#line 1 "/build/doxygen/src/build/generated_src/pyscanner_intermediate.cpp"
#include <stdint.h>
// forward declare yyscan_t to improve type safety
#define YY_TYPEDEF_YY_SCANNER_T
struct yyguts_t;
typedef yyguts_t *yyscan_t;

#line 8 "/build/doxygen/src/build/generated_src/pyscanner_intermediate.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define pyscannerYY_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer pyscannerYY_create_buffer
#endif

#ifdef yy_delete_buffer
#define pyscannerYY_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer pyscannerYY_delete_buffer
#endif

#ifdef yy_scan_buffer
#define pyscannerYY_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer pyscannerYY_scan_buffer
#endif

#ifdef yy_scan_string
#define pyscannerYY_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string pyscannerYY_scan_string
#endif

#ifdef yy_scan_bytes
#define pyscannerYY_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes pyscannerYY_scan_bytes
#endif

#ifdef yy_init_buffer
#define pyscannerYY_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer pyscannerYY_init_buffer
#endif

#ifdef yy_flush_buffer
#define pyscannerYY_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer pyscannerYY_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define pyscannerYY_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state pyscannerYY_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define pyscannerYY_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer pyscannerYY_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define pyscannerYYpush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state pyscannerYYpush_buffer_state
#endif

#ifdef yypop_buffer_state
#define pyscannerYYpop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state pyscannerYYpop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define pyscannerYYensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack pyscannerYYensure_buffer_stack
#endif

#ifdef yylex
#define pyscannerYYlex_ALREADY_DEFINED
#else
#define yylex pyscannerYYlex
#endif

#ifdef yyrestart
#define pyscannerYYrestart_ALREADY_DEFINED
#else
#define yyrestart pyscannerYYrestart
#endif

#ifdef yylex_init
#define pyscannerYYlex_init_ALREADY_DEFINED
#else
#define yylex_init pyscannerYYlex_init
#endif

#ifdef yylex_init_extra
#define pyscannerYYlex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra pyscannerYYlex_init_extra
#endif

#ifdef yylex_destroy
#define pyscannerYYlex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy pyscannerYYlex_destroy
#endif

#ifdef yyget_debug
#define pyscannerYYget_debug_ALREADY_DEFINED
#else
#define yyget_debug pyscannerYYget_debug
#endif

#ifdef yyset_debug
#define pyscannerYYset_debug_ALREADY_DEFINED
#else
#define yyset_debug pyscannerYYset_debug
#endif

#ifdef yyget_extra
#define pyscannerYYget_extra_ALREADY_DEFINED
#else
#define yyget_extra pyscannerYYget_extra
#endif

#ifdef yyset_extra
#define pyscannerYYset_extra_ALREADY_DEFINED
#else
#define yyset_extra pyscannerYYset_extra
#endif

#ifdef yyget_in
#define pyscannerYYget_in_ALREADY_DEFINED
#else
#define yyget_in pyscannerYYget_in
#endif

#ifdef yyset_in
#define pyscannerYYset_in_ALREADY_DEFINED
#else
#define yyset_in pyscannerYYset_in
#endif

#ifdef yyget_out
#define pyscannerYYget_out_ALREADY_DEFINED
#else
#define yyget_out pyscannerYYget_out
#endif

#ifdef yyset_out
#define pyscannerYYset_out_ALREADY_DEFINED
#else
#define yyset_out pyscannerYYset_out
#endif

#ifdef yyget_leng
#define pyscannerYYget_leng_ALREADY_DEFINED
#else
#define yyget_leng pyscannerYYget_leng
#endif

#ifdef yyget_text
#define pyscannerYYget_text_ALREADY_DEFINED
#else
#define yyget_text pyscannerYYget_text
#endif

#ifdef yyget_lineno
#define pyscannerYYget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno pyscannerYYget_lineno
#endif

#ifdef yyset_lineno
#define pyscannerYYset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno pyscannerYYset_lineno
#endif

#ifdef yyget_column
#define pyscannerYYget_column_ALREADY_DEFINED
#else
#define yyget_column pyscannerYYget_column
#endif

#ifdef yyset_column
#define pyscannerYYset_column_ALREADY_DEFINED
#else
#define yyset_column pyscannerYYset_column
#endif

#ifdef yywrap
#define pyscannerYYwrap_ALREADY_DEFINED
#else
#define yywrap pyscannerYYwrap
#endif

#ifdef yyalloc
#define pyscannerYYalloc_ALREADY_DEFINED
#else
#define yyalloc pyscannerYYalloc
#endif

#ifdef yyrealloc
#define pyscannerYYrealloc_ALREADY_DEFINED
#else
#define yyrealloc pyscannerYYrealloc
#endif

#ifdef yyfree
#define pyscannerYYfree_ALREADY_DEFINED
#else
#define yyfree pyscannerYYfree
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define pyscannerYYwrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 253
#define YY_END_OF_BUFFER 254
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_acclist[1531] =
    {   0,
       78,   78,16570,16570,   78,   78,   37,   37,   44,   44,
       52,   52,  254,  252,  253,  250,  253,  251,  252,  253,
       32,  252,  253,   32,  252,  253,   24,  250,  253,   16,
       32,  252,  253,   32,  252,  253,   15,   32,  251,  252,
      253,   28,   32,  252,  253,   29,   32,  252,  253,   30,
       32,  252,  253,   32,  252,  253,   22,   31,   32,  252,
      253,16398,   22,   31,   32,  252,  253,16398,   22,   31,
       32,  252,  253,16398,   22,   31,   32,  252,  253,16398,
       22,   31,   32,  252,  253,16398,   22,   31,   32,  252,
      253,16398,   22,   31,   32,  252,  253,16398,   22,   31,

       32,  252,  253,16398,   22,   31,   32,  252,  253,16398,
       23,   32,  252,  253,   22,   31,   32,  252,  253,16395,
    16396,16397,16398,   22,   31,   32,  252,  253,16395,16396,
    16397,16398,   22,   31,   32,  252,  253,16395,16396,16397,
    16398,   22,   31,   32,  252,  253,16395,16396,16397,16398,
       22,   31,   32,  252,  253,16395,16396,16397,16398,   22,
       31,   32,  252,  253,16395,16396,16397,16398,   22,   31,
       32,  252,  253,16395,16396,16397,16398,   22,   31,   32,
      252,  253,16395,16396,16397,16398,   22,   31,   32,  252,
      253,16395,16396,16397,16398,   66,   67,  252,  253,   63,

      250,  253,   62,   67,  252,  253,   67,  252,  253,   61,
       67,  251,  252,  253,   67,  252,  253,   64,   67,  252,
      253,   65,   67,  252,  253,   65,   67,  252,  253,   65,
       67,  252,  253,   65,   67,  252,  253,   65,   67,  252,
      253,   65,   67,  252,  253,   65,   66,   67,  252,  253,
       91,  252,  253,   78,   91,  252,  253,   94,  250,  253,
       83,   91,  252,  253,   91,  252,  253,   82,   91,  251,
      252,  253,   86,   91,  252,  253,   79,   91,  252,  253,
       79,   91,  252,  253,   77,   91,  252,  253,   90,   91,
      252,  253,   90,   91,  252,  253,   90,   91,  252,  253,

       90,   91,  252,  253,   90,   91,  252,  253,   87,   91,
      252,  253,   91,  252,  253,   90,   91,  252,  253,   88,
       91,  252,  253,  205,  213,  252,  253,  213,  252,  253,
      206,  250,  253,  213,  252,  253,  213,  251,  252,  253,
      213,  252,  253,  213,  252,  253,  204,  213,  252,  253,
      222,  224,  252,  253,  223,  250,  253,  224,  252,  253,
      222,  224,  251,  252,  253,  224,  252,  253,  224,  252,
      253,  222,  224,  252,  253,  214,  224,  252,  253,  252,
      253,  111,  252,  253,  112,  252,  253,  252,  253,  109,
      252,  253,  108,  252,  253,  121,  252,  253,  113,  252,

      253,  121,  252,  253,  121,  251,  252,  253,  118,  252,
      253,  115,  121,  252,  253,  114,  121,  252,  253,  119,
      252,  253,  117,  121,  252,  253,  116,  121,  252,  253,
      101,  105,  252,  253,  105,  252,  253,  104,  250,  253,
    16479,  100,  105,  252,  253,  103,  105,  252,  253,   99,
      105,  251,  252,  253,  101,  105,  252,  253,  101,  105,
      252,  253,  101,  105,  252,  253,   98,  105,  252,  253,
      103,  105,  252,  253,  144,  252,  253,  143,  250,  253,
      142,  144,  252,  253,  141,  144,  251,  252,  253,  135,
      144,  252,  253,  138,  144,  252,  253,  140,  144,  252,

      253,  139,  144,  252,  253,  134,  144,  252,  253,  137,
      144,  252,  253,  133,  144,  252,  253,  136,  144,  252,
      253,  132,  252,  253,  131,  250,  253,  130,  132,  252,
      253,  129,  132,  251,  252,  253,  124,  132,  252,  253,
      127,  132,  252,  253,  128,  132,  252,  253,  123,  132,
      252,  253,  126,  132,  252,  253,  122,  132,  252,  253,
      125,  132,  252,  253,  155,  252,  253,  154,  250,  253,
      153,  155,  252,  253,  152,  155,  251,  252,  253,  147,
      155,  252,  253,  150,  155,  252,  253,  151,  155,  252,
      253,  146,  155,  252,  253,  149,  155,  252,  253,  145,

      155,  252,  253,  148,  155,  252,  253,  168,  252,  253,
      169,  252,  253,  175,  252,  253,  174,  251,  252,  253,
      169,  252,  253,  172,  252,  253,  173,  252,  253,  170,
      252,  253,  171,  252,  253,  252,  253,  180,  250,  253,
     8378,  252,  253,  252,  253, 8378,  252,  253,  251,  252,
      253, 8378,  252,  253, 8378,  252,  253, 8378,  252,  253,
      185,  252,  253,  162,  165,  252,  253,  165,  252,  253,
      163,  250,  253,  161,  165,  252,  253,  165,  252,  253,
      160,  165,  251,  252,  253,  162,  165,  252,  253,  162,
      165,  252,  253,  162,  165,  252,  253,  159,  165,  252,

      253,  190,  250,  253,   91,  189,  252,  253,   91,  252,
      253,  201,  252,  253,  200,  250,  253,  201,  251,  252,
      253,  198,  252,  253,  199,  250,  253,  196,  198,  252,
      253,  195,  198,  251,  252,  253,  191,  198,  252,  253,
      192,  198,  252,  253,  197,  198,  252,  253,  197,  198,
      252,  253,  197,  198,  252,  253,  197,  198,  252,  253,
      229,  230,  252,  253,  230,  252,  253,  228,  230,  251,
      252,  253,  230,  252,  253,  235,  236,  252,  253,  234,
      236,  252,  253,  236,  251,  252,  253,  236,  252,  253,
      239,  241,  252,  253,  239,  240,  250,  253,  239,  241,

      252,  253,  239,  241,  251,  252,  253,  241,  252,  253,
      177,  252,  253,  176,  177,  251,  252,  253,  179,  252,
      253,  178,  179,  252,  253,  179,  251,  252,  253,   38,
      252,  253,   37,   38,  252,  253,   36,  250,  253,   38,
      251,  252,  253,   33,   38,  252,  253,   34,   38,  252,
      253,   34,   38,  252,  253,   49,  252,  253,   44,   49,
      252,  253,   43,  250,  253,   49,  251,  252,  253,   45,
       49,  252,  253,   46,   49,  252,  253,   39,   49,  252,
      253,   47,   49,  252,  253,   42,   49,  252,  253,16424,
    16425,   49,  252,  253,   53,  252,  253,   52,   53,  252,

      253,   51,  250,  253,   53,  251,  252,  253,   50,   53,
      252,  253,   76,  252,  253,   74,  250,  253,   72,   76,
      252,  253,   71,   76,  251,  252,  253,   69,   76,  252,
      253,   70,   76,  252,  253,   68,   76,  252,  253,   73,
       76,  252,  253,   76,  252,  253,  249,  252,  253,  248,
      250,  253,  245,  249,  252,  253,  244,  249,  251,  252,
      253,  246,  249,  252,  253,  247,  249,  252,  253,  249,
      252,  253,  249,  252,  253,  249,  252,  253,16398,   24,
       21,   20,   21,   19,   19,   22,   31,16398,   22,   31,
    16398,   22,   31,16398,   22,   31,16398,   22,   31,16398,

       22,   31,16398,   22,   31,16398,   23,16395,16396,16397,
    16398,16395,16396,16397,16398,16395,16396,16397,16398,16395,
    16396,16397,16398,16395,16396,16397,16398,16395,16396,16397,
    16398,   22,   31,16395,16396,16397,16398, 8205,   22,   31,
    16395,16396,16397,16398,   22,   31,16395,16396,16397,16398,
       22,   31,16395,16396,16397,16398,   22,   31,16395,16396,
    16397,16398,   22,   31,16395,16396,16397,16398,   22,   31,
    16395,16396,16397,16398,   66,   60,   65,   65,   65,   65,
       65,   66,   78,   93,   79,   79,   79,   90,   90,   83,
       82,   90,   90,   89,  205,  212,  212,  212,  204,  222,

      215,  222,  214,  214,  111,  109,  110,  109,  108,  113,
      120,  115,  119,  116,  101,16479,  103,  101,   98,   97,
      102,  103,  168,  169,  173,  180,  184,  183,  185,  162,
      164,  162,  159,  158,  189,  189,  187,  197,  197,  229,
      226,  226,  225,  235,  232,  232,  231,  239,  239,  239,
       37,   34,   34,   44, 8233, 8232,   42,16424,16425,   48,
       52,   50,   75,16398,   25,   21,   20,   21,   27,   26,
       18,   19,   19, 8206,   22,   31,16398,   22,   31,16398,
       22,   31,16398,   22,   31,16398,   22,   31,16398,16395,
    16396,16397,16398,16395,16396,16397,16398,16395,16396,16397,

    16398,16395,16396,16397,16398,16395,16396,16397,16398,16395,
    16396,16397,16398, 8204, 8206, 8204, 8206, 8204, 8206,   22,
       31,16395,16396,16397,16398,   22,   31,16395,16396,16397,
    16398,   22,   31,16395,16396,16397,16398,   22,   31,16395,
    16396,16397,16398,   22,   31,16395,16396,16397,16398,   57,
       60,   59,   58,   65,   65,   84,   93,   92,   85,   80,
       79,   79,   90,   90,  202,  203,  120,   96, 8287, 8287,
      106,  107,  102,  103,  173,  181,  184,  183,  182,  156,
      166,  164,  167,  188,  189,  187,  193,  194,  227,  233,
      237,  238,   34,   34, 8232,   50,  242,  243,   25,   26,

       19,   19,   22,   31,16398,   22,   31,16398,    3,   22,
       31,16398,   22,   31,16398,16395,16396,16397,16398,16395,
    16396,16397,16398,16395,16396,16397,16398,16395,16396,16397,
    16398,16395,16396,16397,16398,   22,   31,16395,16396,16397,
    16398,   22,   31,16395,16396,16397,16398,    1,    3,   22,
       31,16395,16396,16397,16398,   22,   31,16395,16396,16397,
    16398,   57,   58,   84,   85,   80,   79,   90,   81,   90,
      211,  211,  220,  220,  106,  107,  173,  181,  182,  157,
      166,  167,  188,  189,  193,  194,   34,   34,   50,  242,
      243,   19,   19,   22,   31,16398,   22,   31,16398,    8,

       22,   31,16398,16395,16396,16397,16398,16395,16396,16397,
    16398,    1,16395,16396,16397,16398,16395,16396,16397,16398,
       22,   31,16395,16396,16397,16398,   22,   31,16395,16396,
    16397,16398,    7,    8,   22,   31,16395,16396,16397,16398,
    16438,16439,16440,   80,   34,   19,    6,   22,   31,16398,
    16395,16396,16397,16398,16395,16396,16397,16398,    7,16395,
    16396,16397,16398,    5,    6,   22,   31,16395,16396,16397,
    16398, 8246,16438,16439,16440, 8248, 8247,   34,   35,   19,
       10,    5,16395,16396,16397,16398,    9,   10,  208,  210,
      217,  219,   35,   19,    9,  208,  210,  209,  210,  217,

      219,  218,  219,   19,  207,  208,  208,  208,  208,  216,
      217,  217,  217,  217,  221,   19,    4, 8203,    2,    4,
      208,  208,  217,  217,  221,   19,    2,   19,   17,   19
    } ;

static const flex_int16_t yy_accept[767] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    2,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    4,
        5,    5,    5,    6,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    8,
        9,   10,   11,   12,   13,   13,   13,   13,   13,   14,
       16,   18,   21,   24,   27,   30,   34,   37,   42,   46,
       50,   54,   57,   63,   69,   75,   81,   87,   93,   99,
      105,  111,  115,  124,  133,  142,  151,  160,  169,  178,
      187,  196,  200,  203,  207,  210,  215,  218,  222,  226,

      230,  234,  238,  242,  246,  251,  254,  258,  261,  265,
      268,  273,  277,  281,  285,  289,  293,  297,  301,  305,
      309,  313,  316,  320,  324,  328,  331,  334,  337,  341,
      344,  347,  351,  355,  358,  361,  366,  369,  372,  376,
      380,  382,  385,  388,  390,  393,  396,  399,  402,  405,
      409,  412,  416,  420,  423,  427,  431,  435,  438,  442,
      446,  450,  455,  459,  463,  467,  471,  475,  478,  481,
      485,  490,  494,  498,  502,  506,  510,  514,  518,  522,
      525,  528,  532,  537,  541,  545,  549,  553,  557,  561,
      565,  568,  571,  575,  580,  584,  588,  592,  596,  600,

      604,  608,  611,  614,  617,  621,  624,  627,  630,  633,
      636,  638,  641,  644,  646,  649,  652,  655,  658,  661,
      664,  668,  671,  674,  678,  681,  686,  690,  694,  698,
      702,  705,  709,  712,  715,  718,  722,  725,  728,  732,
      737,  741,  745,  749,  753,  757,  761,  765,  768,  773,
      776,  780,  784,  788,  791,  795,  799,  803,  808,  811,
      814,  819,  822,  826,  830,  833,  837,  840,  844,  848,
      852,  856,  859,  863,  866,  870,  874,  878,  882,  886,
      892,  895,  898,  902,  905,  909,  913,  916,  919,  923,
      928,  932,  936,  940,  944,  947,  950,  953,  957,  962,

      966,  970,  973,  976,  979,  979,  979,  980,  981,  981,
      982,  984,  984,  984,  985,  986,  986,  986,  986,  989,
      989,  989,  989,  992,  995,  998, 1001, 1004, 1007, 1008,
     1012, 1016, 1020, 1024, 1028, 1032, 1032, 1038, 1039, 1039,
     1045, 1051, 1057, 1063, 1069, 1075, 1076, 1076, 1077, 1077,
     1077, 1078, 1078, 1078, 1079, 1080, 1081, 1083, 1084, 1084,
     1085, 1085, 1085, 1085, 1086, 1087, 1088, 1088, 1089, 1090,
     1091, 1092, 1093, 1094, 1095, 1096, 1096, 1096, 1096, 1096,
     1097, 1098, 1099, 1100, 1101, 1101, 1102, 1102, 1102, 1102,
     1103, 1104, 1105, 1105, 1106, 1107, 1108, 1109, 1110, 1111,

     1112, 1113, 1114, 1115, 1116, 1117, 1117, 1117, 1117, 1118,
     1118, 1118, 1118, 1119, 1120, 1121, 1123, 1124, 1125, 1125,
     1126, 1126, 1127, 1127, 1128, 1129, 1129, 1129, 1129, 1129,
     1130, 1131, 1131, 1131, 1131, 1132, 1132, 1132, 1132, 1133,
     1134, 1135, 1136, 1137, 1137, 1138, 1138, 1138, 1139, 1139,
     1139, 1140, 1141, 1141, 1142, 1143, 1144, 1145, 1145, 1146,
     1147, 1148, 1149, 1150, 1151, 1152, 1152, 1152, 1153, 1154,
     1155, 1155, 1156, 1157, 1160, 1160, 1161, 1162, 1162, 1162,
     1163, 1164, 1164, 1164, 1164, 1164, 1164, 1165, 1166, 1167,
     1169, 1170, 1171, 1172, 1172, 1173, 1174, 1174, 1174, 1174,

     1175, 1178, 1181, 1184, 1187, 1190, 1194, 1198, 1202, 1206,
     1210, 1214, 1216, 1218, 1220, 1226, 1232, 1238, 1244, 1250,
     1251, 1252, 1253, 1254, 1255, 1256, 1257, 1258, 1259, 1260,
     1261, 1262, 1263, 1264, 1265, 1266, 1267, 1267, 1267, 1267,
     1267, 1267, 1267, 1267, 1268, 1269, 1270, 1271, 1271, 1272,
     1273, 1275, 1276, 1277, 1278, 1279, 1280, 1280, 1281, 1281,
     1282, 1283, 1284, 1286, 1287, 1288, 1289, 1290, 1290, 1291,
     1291, 1292, 1293, 1293, 1294, 1295, 1296, 1296, 1297, 1298,
     1299, 1300, 1301, 1302, 1303, 1303, 1306, 1309, 1310, 1313,
     1316, 1320, 1324, 1328, 1332, 1336, 1336, 1336, 1336, 1342,

     1348, 1350, 1356, 1362, 1363, 1364, 1364, 1365, 1366, 1366,
     1367, 1368, 1369, 1371, 1372, 1373, 1373, 1373, 1373, 1373,
     1374, 1375, 1375, 1375, 1375, 1375, 1375, 1376, 1377, 1378,
     1379, 1380, 1381, 1382, 1383, 1385, 1386, 1387, 1388, 1389,
     1390, 1391, 1392, 1393, 1394, 1397, 1400, 1401, 1404, 1408,
     1412, 1413, 1417, 1421, 1421, 1427, 1433, 1435, 1441, 1444,
     1444, 1445, 1445, 1445, 1445, 1445, 1445, 1446, 1447, 1447,
     1448, 1451, 1455, 1459, 1460, 1464, 1464, 1464, 1466, 1472,
     1472, 1473, 1476, 1477, 1478, 1478, 1478, 1478, 1478, 1478,
     1480, 1481, 1481, 1482, 1482, 1483, 1487, 1487, 1487, 1489,

     1489, 1489, 1490, 1490, 1490, 1490, 1491, 1491, 1491, 1492,
     1492, 1492, 1492, 1493, 1493, 1494, 1495, 1495, 1495, 1496,
     1496, 1496, 1496, 1496, 1497, 1498, 1499, 1500, 1500, 1500,
     1501, 1502, 1503, 1504, 1504, 1505, 1505, 1505, 1505, 1505,
     1506, 1507, 1508, 1509, 1510, 1511, 1512, 1513, 1514, 1515,
     1516, 1517, 1518, 1518, 1519, 1521, 1522, 1523, 1524, 1525,
     1526, 1527, 1528, 1529, 1531, 1531
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    5,    6,    7,    1,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   20,
       20,   20,   20,   20,   20,   21,   21,   22,   23,   24,
       25,   26,    1,   27,   28,   28,   28,   29,   30,   31,
       32,   33,   32,   34,   33,   35,   33,   33,   33,   33,
       33,   36,   33,   37,   38,   33,   33,   39,   33,   33,
       40,   41,   42,    1,   43,   23,   44,   45,   46,   47,

       48,   49,   33,   50,   51,   34,   33,   52,   53,   54,
       55,   56,   33,   57,   58,   59,   60,   33,   33,   39,
       61,   33,   62,   23,   63,    9,    1,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,

       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64
    } ;

static const YY_CHAR yy_meta[65] =
    {   0,
        1,    2,    3,    2,    1,    4,    5,    6,    7,    8,
        9,   10,    1,    7,   10,    7,   11,    7,   12,   12,
       12,   13,    1,    1,   14,    1,   15,   16,   16,   16,
       16,   17,   17,   17,   18,   17,   17,   17,   17,    1,
       19,    1,   17,   16,   16,   16,   16,   16,   16,   17,
       17,   18,   17,   17,   17,   17,   17,   17,   17,   17,
       17,    1,    1,   20
    } ;

static const flex_int16_t yy_base[915] =
    {   0,
        0,    1,   11,   75,  139,    0,  203,    0,  266,  271,
      275,  284,  325,    0,  389,    0,  452,  511,  569,  630,
      691,  752,  813,  874,  937,    0, 1001,    0, 1065, 1125,
     1184, 1243,  277,  293,  280,  294, 1303,    0,  454,  460,
      462,  470,  475,  481,  298,  300,  303,  311, 1367,    0,
     1431,    0, 1495,    0, 1557, 1618,  494,  528, 2360, 5566,
     5566, 5566, 5566,  316, 2351, 2347,    0, 2340, 5566, 5566,
     5566, 2289,  521,  585,  602,  563,  546,  580,  488,  586,
        0,  622,  642,  673, 1680,  624,  655,  642,  670,  690,
        0,    0, 5566, 2340, 2335, 2317, 5566, 5566,    0,  461,

      699, 2274, 2273,  704, 1737, 5566,    4, 5566, 2311, 2309,
     2302, 5566,  731,  725, 5566,    0, 2264,  469, 2247,  731,
     5566, 2296,  763, 5566,    0, 5566, 5566, 2289, 2094,  469,
      502,  320,    0,  553, 5566,    0,  574,  677,  563, 2093,
      774, 5566, 5566, 2070,  533,    0, 5566,  540,    0, 5566,
     5566, 2082, 5566,  546, 5566,    0,    0, 5566,  649, 2086,
        0, 2076,  476,  765,  774,  559, 2075, 5566, 5566, 5566,
     5566, 5566, 5566, 5566, 5566, 5566, 5566, 5566, 5566, 5566,
     5566, 5566, 5566, 5566, 5566, 5566, 5566, 5566, 5566, 5566,
     5566, 5566, 5566, 5566, 5566, 5566, 5566, 5566, 5566, 5566,

     5566,    0,  572, 5566, 5566, 5566, 5566, 2061, 5566, 5566,
      713, 5566, 5566, 2067, 2062, 2051,  483,  776,  781,  717,
        0, 5566, 2048, 2043,    0, 2032,  613,  794,  799,  720,
     5566, 2029,  603, 5566, 5566, 5566, 5566, 5566, 2027, 2020,
     5566, 5566,    0,  652,  801,  826,    0, 2013, 5566,  837,
        0, 5566, 2008,  840, 5566, 5566, 1999, 1982,    0, 5566,
     5566, 5566, 5566, 5566, 5566,  645, 5566, 5566, 5566,  732,
      804, 5566,  682, 5566, 5566, 5566, 5566, 5566, 5566,  848,
      843, 5566,  685, 5566, 5566,  857, 5566, 5566, 5566, 5566,
     5566, 5566, 5566, 5566, 1975, 5566, 5566, 1971, 1960, 5566,

     5566,  719,  858,  860,  791, 1956,  867, 1954, 1947,    0,
        0,    0, 1939,  278,  861,  886,  777,  728,  893,    0,
     1942, 1934, 1072, 1079, 1094, 1098, 1141, 1142, 1132, 1147,
     1193, 1202, 1217, 1568, 1562, 1255, 1260, 5566,  825, 1601,
     1630, 1629, 1663, 1685, 1709,    0, 1934,    0,    0, 1926,
        0, 1925, 1917,  762, 1804, 1800, 1801,  863, 1845,    0,
        0, 1829,  883, 1575, 1752, 5566,    0,    0, 1778, 1823,
     1816, 1738,  881, 5566,    0, 1789, 1778,    0,  425, 5566,
        0,  450,  905,    0,  917, 5566,    0,  659,  861,  921,
     1778, 1773, 1226, 5566,  925, 5566,  928,    0,  929,    0,

     1762, 1075,    0,    0, 1086, 1760, 1865, 1756,    0, 1744,
     1741, 1734,  916, 1112, 5566,    0,    0, 1103,    0, 1719,
     1171, 5566, 1729,    0, 1711, 1698, 1698, 1693, 1079, 1197,
        0, 1687, 1116, 1687,    0, 1673, 1662, 1654, 1089, 1207,
     5566,    0, 1633, 1146,    0, 1647, 1629,    0, 1616, 1608,
     1102,    0, 1594, 5566, 1231, 5566,    0, 1581, 5566, 1284,
     5566, 1579, 1571, 5566, 1156, 1221, 1166, 1254, 1600, 1259,
     1287, 5566, 1264, 1574, 1290, 5566, 1272, 1571, 1293, 1633,
     5566, 1556, 1551, 1295, 1280, 1111, 1694, 1279,    0,    0,
     5566, 1278, 5566,    0,  566, 1196, 1644, 1294, 1718, 5566,

     1926, 1930, 1832, 1931, 1935, 1833, 1950, 1964, 1979, 1991,
     1995, 5566, 1610, 1221, 2010, 2019, 2025, 2041, 2050, 1268,
        0, 5566, 1264, 1243,  509, 1250,    0, 5566, 1247, 1763,
     5566,  583, 1185, 1188, 5566, 5566, 2105, 1180, 1175, 2169,
     1165, 1141, 1126,    0, 5566, 5566, 2233,    0, 1150, 1137,
        0, 1124, 1106,    0, 1079, 1075,    0, 1604, 1634, 1068,
        0, 1065,    0,    0,  929,  907, 5566, 1659, 5566, 1668,
     5566, 5566, 1645, 1697, 1983, 1672, 1675, 1764,  868,  844,
     5566, 5566,  786, 1715, 2055, 2056, 2294, 2072, 2298, 2299,
     2303, 2318, 2333, 2347, 2359, 1790,  777,  771, 2363, 2390,

     2391, 2395, 2417, 5566, 5566,    0, 5566, 5566, 1840, 5566,
     5566,  770,    0, 5566,    0, 2467,    0,  761,  736, 5566,
        0, 2521,    0,  705,  685,  684, 5566, 5566,  657, 5566,
     5566, 5566, 5566, 5566,    0, 5566, 5566, 1836, 2022, 1957,
     5566, 5566,  837, 1113, 2421, 2422, 2426, 2448, 2581, 2582,
     2454, 2455, 2586,  607, 2587, 2611, 2616, 2617, 2633, 1708,
     2069,  602,  565,  554,  545,  530, 2327,  889, 2642, 2647,
     2648, 2662, 2666, 2678, 2690,  511, 2694, 2695, 2709, 2721,
     5566, 2725, 5566, 5566, 2749, 1787, 2752, 1829, 2441, 1965,
     1779,  493, 2760, 2761, 2776, 2777,  470,  471, 2792, 2807,

        0, 2814,    0, 2817, 2362, 2824, 2845,    0, 2848,    0,
     2855, 2451, 2878,  451, 2081, 1154,  458,  444, 2888,  424,
      412,  313, 1162, 2467, 1713, 5566, 2902,  299, 1171, 2520,
     1721, 5566, 2912,  288, 1759, 1969,  230,  210, 1994, 5566,
     2522, 2861, 2908, 2917, 5566, 2919, 2925, 2928, 2934, 2089,
     1998, 2097, 2330, 5566, 2334, 2937, 2945, 2954, 2962, 2337,
     1947, 2366, 1554,  882, 5566, 3003, 3023, 3043, 3063, 3083,
     3103, 3123, 3143, 3163, 3183, 3203, 3223, 3243, 3263, 3283,
     3303, 3323, 3342, 3362, 3367, 3386, 3405, 3424, 3444, 3464,
     3473, 3493, 3502, 3522, 3542, 3562, 3571, 3591, 3600, 3620,

     3639, 3659, 3679, 3688, 3698, 3718, 3738, 3754, 3774, 3794,
     3813, 3822, 3842, 3862, 3882, 3902, 3922, 3941, 3960, 3979,
     3998, 4017, 4037, 4057, 4077, 4089, 4108, 4127, 4147, 4166,
     4185, 4204, 4224, 4244, 4264, 4284, 4293, 4313, 4333, 1121,
     4342, 4362, 4377, 4395, 4410, 4417, 4437, 4446, 4466, 4485,
     4505, 4525, 4534, 4539, 4549, 4569, 4589, 4608, 4628, 4648,
     4667, 4676, 4685, 4705, 4725, 4744, 4763, 4782, 4801, 4820,
     4839, 4859, 4879, 4884, 4896, 4915, 4934, 4953, 4972, 4991,
     5011, 5021, 5041, 2361, 5050, 5070, 5090, 5100, 5120, 5140,
     5159, 5179, 5199, 5208, 5227, 5246, 5265, 5284, 5303, 5315,

     5320, 5339, 5358, 5377, 5397, 5413, 5433, 5449, 5465, 5481,
     5497, 5513, 5529, 5545
    } ;

static const flex_int16_t yy_def[915] =
    {   0,
      766,  766,  765,  765,  765,    5,  765,    7,  767,  767,
      768,  768,  765,   13,  765,   15,  769,  769,  770,  770,
      771,  771,  772,  772,  765,   25,  765,   27,  773,  773,
      774,  774,    7,    7,  775,  775,  765,   37,  776,  776,
      777,  777,  778,  778,  779,  779,  780,  780,  765,   49,
      765,   51,  765,   53,  781,  781,  782,  782,  765,  765,
      765,  765,  765,  783,  765,  765,  784,  765,  765,  765,
      765,  785,  786,  786,  786,   75,   75,   75,   75,   75,
       75,  787,  788,  788,  788,   85,   85,   85,   85,   85,
       85,  789,  765,  765,  790,  765,  765,  765,  791,  791,

      791,  791,  791,  791,  791,  765,  765,  765,  765,  792,
      765,  765,  765,  765,  765,  793,  793,  793,  793,  793,
      765,  765,  793,  765,  794,  765,  765,  765,  765,  765,
      795,  765,  796,  765,  765,  796,  765,  765,  796,  765,
      765,  765,  765,  765,  765,  797,  765,  765,  798,  765,
      765,  765,  765,  765,  765,  799,  800,  765,  801,  765,
      802,  765,  800,  800,  800,  765,  803,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,

      765,  804,  765,  765,  765,  765,  765,  805,  765,  765,
      765,  765,  765,  765,  806,  765,  765,  765,  765,  765,
      807,  765,  808,  765,  809,  765,  807,  807,  807,  765,
      765,  810,  811,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  812,  812,  812,  812,  813,  765,  765,  814,
      815,  765,  765,  816,  765,  765,  765,  765,  817,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  818,
      818,  765,  765,  765,  765,  765,  765,  765,  765,  819,
      765,  765,  765,  765,  765,  820,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,

      765,  765,  765,  765,  821,  765,  822,  765,  765,  823,
      824,  825,  765,  826,  826,  765,  765,  827,  828,  829,
      765,  765,  828,  828,  828,  828,  828,  828,  830,  831,
      831,  831,  831,  831,  831,  765,  832,  765,  833,  832,
      832,  832,  832,  832,  832,  834,  765,  835,  836,  765,
      837,  765,  765,  837,  837,  837,  837,  765,  765,  838,
      839,  765,  765,  765,  765,  765,  840,  841,  841,  765,
      765,  841,  841,  765,  842,  765,  765,  843,  765,  765,
      843,  765,  765,  844,  765,  765,  845,  765,  765,  844,
      765,  765,  765,  765,  765,  765,  765,  846,  765,  847,

      765,  765,  848,  849,  850,  765,  765,  765,  851,  765,
      765,  765,  849,  765,  765,  852,  853,  765,  854,  855,
      765,  765,  765,  856,  765,  765,  765,  765,  765,  765,
      857,  765,  858,  765,  859,  765,  765,  765,  857,  765,
      765,  860,  860,  861,  862,  765,  765,  863,  765,  765,
      863,  864,  765,  765,  765,  765,  865,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  866,  867,  867,  765,
      765,  765,  765,  868,  765,  765,  765,  765,  869,  870,
      765,  765,  765,  765,  765,  765,  871,  765,  872,  873,
      765,  765,  765,  874,  875,  875,  765,  876,  877,  765,

      878,  878,  878,  878,  878,  879,  879,  879,  879,  879,
      879,  765,  765,  765,  880,  880,  880,  880,  880,  765,
      881,  765,  765,  882,  882,  765,  883,  765,  765,  765,
      765,  884,  885,  885,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  886,  765,  765,  765,  547,  765,  765,
      887,  888,  765,  889,  765,  765,  890,  765,  891,  765,
      892,  765,  893,  894,  765,  765,  765,  765,  765,  765,
      765,  765,  895,  896,  897,  765,  898,  899,  765,  765,
      765,  765,  900,  875,  877,  878,  878,  765,  878,  878,
      879,  879,  879,  879,  879,  765,  765,  765,  880,  880,

      765,  880,  880,  765,  765,  901,  765,  765,  765,  765,
      765,  885,  885,  765,  537,  537,  537,  765,  765,  765,
      540,  540,  540,  765,  765,  765,  765,  765,  888,  765,
      765,  765,  765,  765,  893,  765,  765,  896,  897,  899,
      765,  765,  900,  875,  878,  878,  765,  878,  879,  879,
      765,  879,  879,  765,  880,  880,  765,  880,  902,  765,
      765,  765,  765,  765,  765,  765,  897,  875,  765,  765,
      878,  879,  879,  765,  879,  765,  765,  765,  880,  765,
      765,  902,  765,  765,  903,  765,  904,  765,  765,  897,
      875,  765,  765,  765,  765,  879,  765,  765,  765,  903,

      905,  903,  906,  903,  765,  765,  904,  907,  904,  908,
      904,  765,  765,  765,  765,  875,  765,  765,  765,  765,
      765,  905,  909,  910,  765,  765,  765,  907,  911,  912,
      765,  765,  765,  765,  875,  765,  765,  765,  765,  765,
      913,  913,  910,  910,  765,  914,  914,  912,  912,  765,
      875,  765,  765,  765,  765,  913,  913,  914,  914,  765,
      875,  765,  875,  875,    0,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,

      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,

      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765
    } ;

static const flex_int16_t yy_nxt[5631] =
    {   0,
      765,  765,   61,   61,  311,  358,  312,  358,  765,   62,
       62,   63,   64,   65,   64,   63,   66,   67,   63,   63,
       68,   69,   70,   63,   63,   63,   63,   63,   63,   63,
       63,   63,   63,   63,   63,   71,   63,   72,   73,   73,
       73,   73,   73,   73,   73,   73,   74,   73,   75,   73,
       63,   63,   63,   73,   76,   73,   77,   78,   73,   79,
       73,   80,   73,   73,   73,   73,   73,   74,   73,   73,
       81,   73,   63,   63,   73,   63,   82,   65,   82,   63,
       66,   67,   63,   63,   68,   69,   70,   63,   63,   63,
       63,   63,   63,   63,   63,   63,   63,   63,   63,   71,

       63,   72,   83,   83,   83,   83,   83,   83,   83,   83,
       84,   83,   85,   83,   63,   63,   63,   83,   86,   83,
       87,   88,   83,   89,   83,   90,   83,   83,   83,   83,
       83,   84,   83,   83,   91,   83,   63,   63,   83,   92,
       92,   93,   92,   92,   94,   95,   92,   92,   96,   92,
       92,   92,   92,   92,   92,   97,   92,   92,   92,   92,
       92,   92,   92,   98,   92,   92,   99,   99,   99,   99,
       99,   99,   99,   99,  100,   99,  101,   99,   92,   92,
       92,   99,   99,   99,  102,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   99,  100,  103,   99,  104,   99,

       92,   92,  105,  106,  107,  108,  107,  106,  109,  110,
      106,  106,  111,  112,  106,  106,  106,  106,  106,  106,
      106,  113,  114,  114,  106,  106,  106,  115,  106,  106,
      116,  116,  116,  117,  116,  116,  116,  116,  118,  119,
      120,  116,  121,  122,  106,  116,  116,  116,  116,  116,
      116,  116,  116,  116,  116,  116,  116,  116,  116,  118,
      116,  116,  123,  116,  124,  106,  116,  126,  127,  126,
      754,  128,  132,  127,  132,  129,  128,  134,  753,  231,
      129,  135,  235,  232,  136,  139,  134,  139,  493,  236,
      140,  750,  130,  136,  494,  231,  235,  130,  233,  232,

       61,  137,   61,  236,  745,   61,  131,  261,  263,  261,
      137,  131,  264,   61,  233,  138,  263,  305,  740,  305,
      264,  383,  306,  383,  138,   60,  141,   61,  141,   60,
       60,   60,   60,   60,   62,  142,  143,   60,   60,   60,
      144,   60,   60,   60,   60,   60,  145,   60,   60,   60,
       60,   60,  146,  146,  146,  146,  146,  146,  146,  146,
      146,  146,  146,  146,   60,   60,   60,  146,  146,  146,
      146,  146,  146,  146,  146,  146,  146,  146,  146,  146,
      146,  146,  146,  146,  146,  146,   60,   60,  146,  147,
      148,   61,  148,  147,  147,  149,  147,  147,  150,   60,

      151,  152,  147,  153,  147,  147,  147,  147,  147,  147,
      154,  147,  147,  155,  147,  147,  156,  156,  156,  156,
      156,  156,  156,  156,  156,  156,  156,  156,  147,  147,
      147,  156,  156,  156,  156,  156,  156,  156,  156,  156,
      156,  156,  156,  156,  156,  156,  156,  156,  156,  156,
      147,  147,  156,  158,  159,  158,   61,  160,  161,  248,
      739,  162,   61,  249,   61,  248,  352,  252,  158,  249,
      353,  253,   61,  538,  370,  252,  539,  256,  371,  253,
      257,  411,  738,  256,  258,  412,  257,  163,  427,  164,
      258,  737,  428,  765,  250,  378,  297,  765,  538,  298,

      250,  539,  254,  299,  300,  301,  736,  734,  163,  378,
      254,  165,  166,  159,  166,  259,  160,  167,  721,  379,
      162,  259,  316,  319,  316,  765,  720,  158,  381,  302,
      297,  303,  317,  298,  397,  318,  397,  299,  300,  301,
      717,  399,  381,  399,  327,  320,  163,  402,  164,  402,
      302,  765,  382,  304,  385,  765,  385,  524,  697,  386,
      414,  415,  414,  302,  390,  303,  390,  163,  765,  391,
      165,  169,  765,  418,  170,  418,  493,  689,  171,  172,
      173,  319,  494,  174,  302,  765,  316,  304,  316,  765,
      321,  765,  688,  175,  322,  765,  317,  325,  319,  318,

      387,  687,  319,  316,  444,  316,  444,  321,  176,  320,
      177,  322,  686,  317,  387,  319,  318,  611,  437,  319,
      324,  319,  438,  329,  388,  329,  320,  326,  306,  765,
      178,  179,  169,  765,  611,  170,  319,  323,  328,  171,
      172,  173,  319,  336,  174,  336,  465,  765,  465,  685,
      405,  765,  405,  317,  175,  406,  318,  449,  323,  337,
      765,  450,  676,  338,  765,  331,  339,  332,  333,  176,
      334,  177,  335,  419,  336,  765,  336,  337,  321,  765,
      337,  341,  322,  470,  317,  470,  477,  318,  477,  343,
      337,  178,  179,  181,  338,  765,  182,  339,  337,  765,

      183,  184,  185,  387,  352,  337,  342,  541,  353,  352,
      542,  337,  186,  353,  421,  422,  421,  387,  430,  422,
      430,  440,  441,  440,  484,  337,  344,  389,  485,  498,
      187,  498,  188,  466,  354,  466,  370,  666,  665,  354,
      371,  363,  345,  365,  365,  365,  337,  363,  467,  364,
      364,  365,  189,  190,  181,  354,  664,  182,  366,  366,
      354,  183,  184,  185,  366,  366,  373,  352,  370,  367,
      411,  353,  371,  186,  412,  393,  366,  393,  497,  411,
      497,  427,  366,  412,  394,  428,  427,  373,  317,  663,
      428,  187,  305,  188,  305,  395,  493,  306,  373,  437,

      413,  320,  494,  438,  437,  466,  449,  466,  438,  413,
      450,  429,  662,  189,  190,  192,  429,  613,  193,  373,
      467,  413,  194,  195,  196,  654,  513,  197,  513,  439,
      413,  449,  429,  598,  439,  450,  451,  429,  455,  456,
      455,  460,  461,  460,  475,  476,  475,  493,  642,  471,
      439,  471,  198,  494,  199,  439,  469,  451,  478,  472,
      478,  451,  473,  484,  358,  484,  358,  485,  316,  485,
      316,  493,  641,  479,  200,  201,  192,  494,  317,  193,
      514,  318,  451,  194,  195,  196,  370,  316,  197,  316,
      371,  320,  493,  486,  316,  486,  316,  317,  494,  493,

      318,  530,  530,  530,  317,  494,  383,  318,  383,  541,
      320,  637,  543,  198,  486,  199,  486,  320,  385,  496,
      385,  411,  390,  386,  390,  412,  397,  391,  397,  397,
      399,  397,  399,  636,  691,  200,  201,   60,   60,   61,
       60,   60,   60,   60,   60,   60,   62,   60,   60,   60,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   60,   60,  202,  202,  202,  202,  202,  202,
      202,  202,  202,  202,  202,  202,   60,   60,   60,  202,
      202,  202,  202,  202,  202,  202,  202,  202,  202,  202,
      202,  202,  202,  202,  202,  202,  202,  202,   60,   60,

      202,   60,  203,   61,  203,   60,  204,   60,   60,   60,
      205,  206,  206,   60,   60,  206,   60,   60,   60,   60,
       60,   60,  207,   60,   60,   60,   60,   60,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      209,   60,  210,  208,  208,  208,  208,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  208,   60,   60,  208,   60,  211,  212,  211,  634,
      214,  215,  633,  316,  216,  316,  402,  321,  402,  631,
      316,  322,  316,  317,  427,  555,  318,  405,  428,  405,
      317,   60,  406,  318,  437,  316,  320,  316,  438,  316,

      217,  316,  218,  320,  418,  317,  418,  449,  318,  317,
      630,  450,  318,  414,  415,  414,  484,  558,  320,  558,
      485,  217,  320,  493,  219,   60,  220,  212,  220,  494,
      214,  215,  532,  329,  216,  329,  532,  502,  306,  501,
      419,  628,  316,  316,  316,  316,  503,  444,  336,  444,
      336,   60,  317,  317,  627,  318,  318,  465,  317,  465,
      217,  318,  218,  668,  493,  320,  320,  573,  338,  573,
      494,  339,  421,  422,  421,  331,  626,  332,  333,  742,
      334,  217,  335,  742,  219,  222,  223,  222,  747,  224,
      225,  625,  747,  226,  336,  504,  336,  505,  430,  422,

      430,  735,  742,  336,  317,  336,  493,  318,  440,  441,
      440,  747,  494,  317,  338,  624,  318,  339,  336,  227,
      336,  228,  466,  338,  466,  619,  339,  393,  317,  393,
      618,  318,  568,  456,  568,  613,  394,  467,  338,  584,
      227,  339,  612,  229,  230,  223,  230,  395,  224,  225,
      507,  608,  226,  508,  607,  466,  336,  466,  336,  606,
      470,  336,  470,  336,  509,  576,  317,  576,  605,  318,
      467,  317,  604,  477,  318,  477,  338,  598,  227,  339,
      228,  338,  582,  581,  339,  570,  461,  570,  471,  483,
      471,  475,  476,  475,  577,  498,  577,  498,  472,  227,

      482,  473,  229,  237,  237,  238,  237,  237,  239,  237,
      237,  237,  240,  241,  242,  237,  237,  237,  237,  237,
      237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
      243,  243,  243,  243,  243,  243,  243,  243,  244,  243,
      245,  243,  241,  237,  242,  243,  243,  243,  243,  243,
      243,  243,  243,  243,  243,  243,  243,  243,  243,  244,
      243,  243,  246,  243,  241,  242,  243,  265,  266,  267,
      266,  265,  265,  265,  265,  265,  268,  265,  265,  265,
      265,  265,  265,  269,  265,  265,  265,  265,  265,  265,
      265,  265,  265,  265,  270,  270,  270,  270,  270,  270,

      270,  270,  270,  270,  270,  270,  265,  265,  265,  270,
      270,  270,  270,  270,  270,  270,  270,  271,  270,  270,
      270,  270,  270,  270,  270,  270,  270,  270,  265,  265,
      270,  272,  273,  274,  273,  272,  272,  272,  272,  272,
      275,  276,  277,  278,  272,  279,  272,  272,  272,  272,
      272,  272,  272,  272,  272,  272,  272,  272,  280,  280,
      280,  280,  280,  280,  280,  280,  280,  280,  280,  280,
      272,  281,  272,  280,  280,  280,  280,  280,  280,  280,
      280,  280,  280,  280,  280,  280,  280,  280,  280,  280,
      280,  280,  272,  272,  280,  282,  283,  284,  283,  282,

      282,  282,  282,  282,  285,  282,  282,  282,  282,  282,
      282,  282,  282,  282,  282,  282,  282,  282,  282,  282,
      282,  282,  286,  286,  286,  286,  286,  286,  286,  286,
      286,  286,  286,  286,  282,  282,  282,  286,  286,  286,
      286,  286,  286,  286,  286,  286,  286,  286,  286,  286,
      286,  286,  286,  286,  286,  286,  282,  282,  286,  288,
      580,  579,  289,  336,  493,  336,  290,  291,  292,  336,
      494,  336,  478,  317,  478,  471,  318,  471,  293,  317,
      572,  294,  318,  338,  571,  472,  339,  479,  473,  338,
      569,  363,  339,  364,  364,  365,  291,  295,  292,  567,

      764,  466,  336,  466,  336,  558,  321,  558,  366,  531,
      322,  596,  317,  596,  511,  318,  467,  447,  291,  292,
      288,  446,  338,  289,  510,  339,  531,  290,  291,  292,
      336,  336,  336,  336,  478,  558,  478,  558,  566,  293,
      317,  317,  294,  318,  318,  497,  573,  497,  573,  479,
      338,  338,  565,  339,  339,  575,  563,  291,  295,  292,
      568,  456,  568,  436,  336,  597,  336,  434,  320,  570,
      461,  570,  516,  576,  317,  576,  577,  318,  577,  291,
      292,  336,  562,  336,  338,  321,  336,  339,  336,  322,
      515,  317,  560,  557,  318,  316,  317,  316,  466,  318,

      466,  338,  426,  423,  339,  317,  338,  556,  318,  339,
      336,  517,  336,  467,  725,  340,  725,  555,  320,  316,
      317,  316,  731,  318,  731,  493,  661,  661,  661,  317,
      338,  494,  318,  339,  553,  419,  340,  346,  346,  518,
      346,  346,  320,  410,  346,  346,  408,  346,  346,  346,
      346,  346,  346,  550,  346,  357,  357,  357,  346,  346,
      346,  549,  346,  346,  519,  478,  545,  478,  363,  493,
      365,  365,  365,  644,  401,  494,  346,  346,  346,  392,
      479,  530,  530,  530,  392,  366,  366,  536,  705,  493,
      705,  596,  609,  596,  535,  494,  610,  534,  346,  346,

      357,  346,  346,  366,  346,  346,  706,  706,  346,  346,
      609,  346,  346,  346,  346,  346,  346,  751,  346,  357,
      357,  357,  346,  346,  346,  362,  346,  346,  359,  533,
      712,  716,  712,  588,  336,  588,  336,  466,  529,  466,
      346,  346,  346,  317,  317,  597,  318,  318,  713,  713,
      526,  525,  467,  660,  338,  660,  320,  339,  661,  661,
      661,  524,  346,  346,  357,  546,  546,  546,  546,  546,
      546,  546,  546,  546,  546,  546,  546,  546,  546,  546,
      546,  546,  546,  547,  547,  547,  546,  546,  546,  546,
      546,  546,  547,  548,  548,  547,  548,  547,  547,  548,

      548,  548,  547,  547,  546,  546,  546,  548,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  350,  316,  547,  316,
      347,  316,  316,  316,  316,  523,  316,  317,  316,  520,
      318,  317,  317,  313,  318,  318,  317,  309,  492,  318,
      320,  336,  488,  336,  320,  320,  308,  493,  478,  320,
      478,  317,  312,  494,  318,  336,  715,  336,  715,  483,
      752,  338,  752,  479,  339,  317,  482,  481,  318,  586,
      336,  467,  336,  589,  466,  338,  466,  587,  339,  590,
      317,  463,  336,  318,  336,  755,  336,  755,  336,  467,

      338,  763,  317,  339,  462,  318,  317,  592,  493,  318,
      591,  336,  338,  336,  494,  339,  338,  458,  453,  339,
      336,  317,  336,  466,  318,  466,  601,  593,  601,  447,
      317,  338,  446,  318,  339,  443,  317,  639,  467,  318,
      338,  436,  336,  339,  336,  594,  338,  761,  434,  339,
      595,  336,  317,  336,  432,  318,  316,  316,  316,  316,
      426,  317,  338,  599,  318,  339,  317,  317,  425,  318,
      318,  338,  423,  588,  339,  588,  600,  419,  667,  320,
      320,  409,  715,  317,  715,  410,  318,  661,  661,  661,
      760,  408,  760,  602,  401,  396,  320,  467,  752,  392,

      752,  645,  610,  377,  603,  614,  614,  614,  614,  614,
      614,  614,  615,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  616,  616,  616,  614,  614,  614,  614,
      614,  614,  617,  617,  617,  617,  617,  617,  617,  617,
      617,  617,  617,  617,  614,  614,  614,  617,  617,  617,
      617,  617,  617,  617,  617,  617,  617,  617,  617,  617,
      617,  617,  617,  617,  617,  617,  614,  614,  614,  620,
      620,  620,  620,  620,  620,  620,  621,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  622,  622,  622,
      620,  620,  620,  620,  620,  620,  623,  623,  623,  623,

      623,  623,  623,  623,  623,  623,  623,  623,  620,  620,
      620,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      620,  620,  620,  546,  546,  546,  546,  546,  546,  546,
      546,  546,  546,  546,  546,  546,  546,  546,  546,  546,
      546,  547,  547,  547,  546,  546,  546,  546,  546,  546,
      547,  548,  548,  547,  548,  547,  547,  548,  548,  548,
      547,  547,  546,  546,  546,  548,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  376,  316,  547,  316,  374,  647,

      316,  647,  316,  372,  336,  317,  336,  369,  318,  317,
      317,  362,  318,  318,  317,  361,  359,  318,  320,  336,
      356,  336,  320,  320,  338,  355,  350,  339,  466,  317,
      466,  762,  318,  762,  651,  755,  651,  755,  760,  338,
      760,  349,  339,  467,  317,  347,  315,  318,  336,  313,
      336,  646,  309,  308,  338,  648,  649,  339,  317,  765,
      336,  318,  336,  705,  336,  705,  336,  762,  338,  762,
      317,  339,  532,  318,  317,  650,  532,  318,  532,  765,
      338,  706,  706,  339,  338,  690,  765,  339,  765,  765,
      765,  336,  601,  336,  601,  765,  657,  765,  657,  652,

      765,  317,  317,  765,  318,  318,  317,  765,  655,  318,
      765,  338,  338,  653,  339,  339,  338,  765,  336,  339,
      336,  765,  669,  670,  669,  670,  765,  647,  317,  647,
      765,  318,  317,  317,  765,  318,  318,  317,  338,  765,
      318,  339,  712,  765,  712,  320,  320,  656,  765,  316,
      320,  316,  712,  765,  712,  651,  674,  651,  674,  317,
      713,  713,  318,  765,  765,  317,  317,  765,  318,  318,
      713,  713,  320,  658,  614,  338,  338,  765,  339,  339,
      765,  765,  765,  703,  744,  714,  765,  765,  744,  765,
      765,  765,  765,  765,  616,  616,  616,  616,  616,  616,

      616,  616,  616,  616,  616,  616,  671,  744,  765,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  620,  765,
      765,  765,  765,  765,  765,  765,  710,  749,  723,  757,
      765,  749,  765,  757,  765,  765,  765,  765,  622,  622,
      622,  622,  622,  622,  622,  622,  622,  622,  622,  622,
      749,  765,  757,  622,  622,  622,  622,  622,  622,  622,
      622,  622,  622,  622,  622,  622,  622,  622,  622,  622,
      622,  622,  336,  336,  336,  336,  765,  336,  677,  336,
      677,  765,  317,  317,  765,  318,  318,  317,  317,  765,

      318,  318,  338,  338,  765,  339,  339,  338,  338,  765,
      339,  339,  678,  765,  678,  765,  765,  657,  336,  657,
      336,  765,  317,  765,  765,  318,  672,  317,  317,  765,
      318,  318,  338,  765,  680,  339,  680,  338,  338,  673,
      339,  339,  675,  669,  681,  669,  765,  681,  670,  693,
      670,  693,  765,  317,  683,  765,  318,  684,  317,  317,
      765,  318,  318,  694,  765,  694,  320,  695,  765,  695,
      765,  320,  320,  317,  765,  679,  318,  317,  765,  674,
      318,  674,  765,  338,  765,  765,  339,  338,  692,  317,
      339,  336,  318,  336,  765,  677,  678,  677,  678,  338,

      765,  317,  339,  765,  318,  317,  317,  765,  318,  318,
      699,  338,  699,  765,  339,  338,  338,  765,  339,  339,
      317,  765,  680,  318,  680,  765,  680,  765,  680,  765,
      338,  765,  681,  339,  765,  681,  681,  765,  765,  681,
      698,  765,  683,  765,  765,  684,  683,  765,  696,  684,
      700,  765,  700,  707,  701,  707,  765,  708,  765,  765,
      765,  693,  694,  693,  694,  703,  704,  765,  710,  711,
      704,  317,  317,  711,  318,  318,  765,  695,  719,  695,
      719,  765,  338,  765,  320,  339,  765,  317,  317,  704,
      318,  318,  711,  699,  765,  699,  765,  338,  338,  765,

      339,  339,  765,  317,  765,  765,  318,  718,  700,  765,
      700,  765,  701,  338,  765,  765,  339,  765,  765,  765,
      765,  765,  765,  703,  704,  725,  726,  725,  704,  765,
      723,  704,  765,  703,  704,  704,  765,  765,  704,  765,
      726,  765,  727,  727,  727,  765,  707,  704,  707,  765,
      708,  765,  765,  765,  704,  765,  765,  704,  765,  765,
      765,  710,  711,  765,  729,  711,  711,  765,  765,  711,
      765,  710,  711,  765,  765,  765,  711,  703,  757,  731,
      732,  731,  757,  765,  765,  711,  765,  765,  711,  719,
      765,  719,  765,  765,  732,  711,  733,  733,  733,  317,

      765,  757,  318,  725,  726,  725,  765,  765,  765,  338,
      765,  765,  339,  731,  732,  731,  765,  765,  726,  765,
      727,  727,  727,  765,  703,  744,  765,  765,  732,  744,
      733,  733,  733,  703,  744,  729,  759,  765,  744,  765,
      759,  710,  759,  765,  710,  749,  759,  765,  744,  749,
      710,  749,  765,  723,  757,  749,  765,  744,  757,  759,
      765,  703,  757,  765,  765,  759,  757,  765,  749,  765,
      729,  759,  765,  765,  749,  759,  765,  757,  710,  759,
      765,  765,  765,  759,  765,  757,  765,  765,  765,  765,
      765,  765,  765,  765,  759,  765,  765,  765,  765,  765,

      765,  765,  759,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   60,  125,  125,  125,  125,  125,  125,  125,
      125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
      125,  125,  125,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  157,  157,  157,  157,  157,  157,  157,
      157,  157,  157,  157,  157,  157,  157,  157,  157,  157,
      157,  157,  157,  168,  168,  168,  168,  168,  168,  168,
      168,  168,  168,  168,  168,  168,  168,  168,  168,  168,

      168,  168,  168,  180,  180,  180,  180,  180,  180,  180,
      180,  180,  180,  180,  180,  180,  180,  180,  180,  180,
      180,  180,  180,  191,  191,  191,  191,  191,  191,  191,
      191,  191,  191,  191,  191,  191,  191,  191,  191,  191,
      191,  191,  191,  213,  213,  213,  213,  213,  213,  213,
      213,  213,  213,  213,  213,  213,  213,  213,  213,  213,
      213,  213,  213,  221,  221,  221,  221,  221,  221,  221,
      221,  221,  221,  221,  221,  221,  221,  221,  221,  221,
      221,  221,  221,  234,  234,  234,  234,  234,  234,  234,
      234,  234,  234,  234,  234,  234,  234,  234,  234,  234,

      234,  234,  234,  247,  247,  247,  247,  247,  247,  247,
      247,  247,  247,  247,  247,  247,  247,  247,  247,  247,
      247,  247,  247,  251,  251,  251,  251,  251,  251,  251,
      251,  251,  251,  251,  251,  251,  251,  251,  251,  251,
      251,  251,  251,  255,  255,  255,  255,  255,  255,  255,
      255,  255,  255,  255,  255,  255,  255,  255,  255,  255,
      255,  255,  255,  260,  260,  260,  260,  260,  260,  260,
      260,  260,  260,  260,  260,  260,  260,  260,  260,  260,
      260,  260,  260,  262,  262,  262,  262,  262,  262,  262,
      262,  262,  262,  262,  262,  262,  262,  262,  262,  262,

      262,  262,  262,  287,  287,  287,  287,  287,  287,  287,
      287,  287,  287,  287,  287,  287,  287,  287,  287,  287,
      287,  287,  287,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  307,  765,  765,  307,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  307,  307,  307,
      765,  307,  310,  310,  765,  310,  310,  310,  310,  310,
      310,  310,  310,  310,  310,  310,  310,  310,  310,  310,
      310,  310,  314,  314,  314,  765,  314,  319,  765,  765,
      765,  765,  765,  765,  765,  319,  765,  319,  765,  319,

      765,  319,  319,  319,  765,  319,  330,  765,  765,  330,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      330,  330,  330,  765,  330,  337,  765,  765,  765,  765,
      765,  765,  765,  337,  765,  337,  337,  337,  765,  337,
      337,  337,  765,  337,  346,  346,  765,  765,  765,  346,
      346,  765,  346,  346,  765,  346,  346,  765,  346,  765,
      765,  765,  346,  346,  348,  348,  765,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  351,  765,  765,  765,  351,  351,
      351,  765,  351,  360,  360,  765,  360,  360,  360,  360,

      360,  360,  360,  360,  360,  360,  360,  360,  360,  360,
      360,  360,  360,  368,  765,  765,  765,  368,  368,  368,
      765,  368,  375,  765,  765,  765,  375,  375,  375,  765,
      375,  375,  375,  375,  375,  375,  765,  375,  375,  375,
      765,  375,  380,  380,  765,  380,  380,  380,  380,  380,
      380,  380,  380,  380,  380,  380,  380,  380,  380,  380,
      380,  380,  384,  384,  765,  384,  765,  384,  384,  384,
      384,  384,  384,  384,  384,  384,  765,  384,  384,  384,
      765,  384,  398,  765,  765,  765,  398,  398,  398,  765,
      398,  400,  400,  765,  400,  765,  400,  400,  400,  400,

      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  403,  765,  765,  765,  403,  403,  403,  765,  403,
      404,  765,  765,  765,  765,  404,  404,  765,  404,  404,
      765,  404,  404,  404,  404,  404,  404,  404,  404,  404,
      407,  765,  765,  407,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  407,  407,  407,  765,  407,  409,
      409,  765,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  416,
      416,  765,  416,  416,  416,  416,  416,  416,  416,  416,
      416,  416,  416,  416,  416,  416,  416,  416,  416,  417,

      765,  765,  765,  417,  417,  417,  765,  417,  420,  420,
      765,  765,  765,  420,  420,  420,  765,  420,  424,  424,
      765,  424,  424,  424,  424,  424,  424,  424,  424,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  431,  765,
      765,  765,  765,  431,  431,  765,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  433,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  433,
      433,  433,  765,  433,  435,  435,  765,  435,  765,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  442,  442,  765,  442,  442,  442,

      442,  442,  442,  442,  442,  442,  442,  442,  442,  442,
      442,  442,  442,  442,  445,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  445,  445,
      445,  765,  445,  448,  765,  765,  765,  448,  448,  448,
      765,  448,  452,  452,  765,  765,  452,  452,  452,  765,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      765,  452,  454,  454,  454,  454,  454,  454,  454,  454,
      454,  454,  454,  454,  454,  454,  454,  454,  454,  454,
      454,  454,  457,  457,  765,  765,  457,  457,  457,  765,
      457,  457,  457,  457,  457,  457,  457,  457,  457,  457,

      765,  457,  459,  459,  459,  459,  459,  459,  459,  459,
      459,  459,  459,  459,  459,  459,  459,  459,  459,  459,
      459,  459,  464,  464,  765,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  468,  765,  765,  765,  765,  765,  765,  765,
      765,  468,  468,  765,  765,  765,  468,  468,  468,  765,
      468,  474,  765,  765,  765,  765,  765,  765,  765,  474,
      765,  474,  765,  765,  765,  474,  474,  474,  765,  474,
      480,  765,  765,  765,  765,  765,  765,  765,  765,  480,
      480,  765,  765,  765,  480,  480,  480,  765,  480,  307,

      765,  765,  307,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  307,  307,  307,  765,  307,  487,  765,
      765,  765,  765,  765,  765,  765,  487,  765,  487,  765,
      487,  765,  487,  487,  487,  765,  487,  489,  489,  765,
      489,  489,  489,  489,  489,  489,  489,  489,  489,  489,
      489,  489,  489,  489,  489,  489,  489,  490,  490,  765,
      490,  490,  490,  490,  490,  490,  490,  490,  490,  490,
      490,  490,  490,  490,  490,  490,  490,  491,  491,  491,
      491,  765,  491,  491,  491,  491,  491,  491,  491,  491,
      491,  491,  491,  491,  491,  491,  491,  495,  765,  495,

      495,  765,  765,  765,  495,  495,  495,  765,  495,  499,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  499,  499,  499,  765,  499,  319,  765,
      765,  765,  765,  765,  765,  765,  319,  765,  319,  765,
      319,  765,  319,  319,  319,  765,  319,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      765,  500,  500,  500,  500,  500,  500,  330,  765,  765,
      330,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  330,  330,  330,  765,  330,  506,  765,  765,  765,
      765,  765,  765,  765,  506,  765,  506,  506,  506,  765,

      506,  506,  506,  765,  506,  337,  765,  765,  765,  765,
      765,  765,  765,  337,  765,  337,  337,  337,  765,  337,
      337,  337,  765,  337,  512,  512,  512,  512,  512,  512,
      512,  512,  512,  512,  512,  512,  512,  765,  512,  512,
      512,  512,  512,  512,  346,  346,  765,  765,  765,  346,
      346,  765,  346,  346,  765,  346,  346,  765,  346,  765,
      765,  765,  346,  346,  521,  521,  765,  521,  521,  521,
      521,  521,  521,  521,  521,  521,  521,  521,  521,  521,
      521,  521,  521,  521,  522,  522,  522,  522,  765,  522,
      522,  522,  522,  522,  522,  522,  522,  522,  522,  522,

      522,  522,  522,  522,  351,  765,  765,  765,  351,  351,
      351,  765,  351,  527,  527,  765,  527,  527,  527,  527,
      527,  527,  527,  527,  527,  527,  527,  527,  527,  527,
      527,  527,  527,  528,  528,  528,  528,  765,  528,  528,
      528,  528,  528,  528,  528,  528,  528,  528,  528,  528,
      528,  528,  528,  368,  765,  765,  765,  368,  368,  368,
      765,  368,  375,  765,  765,  765,  375,  375,  375,  765,
      375,  375,  375,  375,  375,  375,  765,  375,  375,  375,
      765,  375,  537,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  537,  537,  537,  384,  384,  765,  384,  765,

      384,  384,  384,  384,  384,  384,  384,  384,  384,  765,
      384,  384,  384,  765,  384,  540,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  540,  540,  540,  398,  765,
      765,  765,  398,  398,  398,  765,  398,  544,  544,  765,
      544,  544,  544,  544,  544,  544,  544,  544,  544,  544,
      544,  544,  544,  544,  544,  544,  544,  403,  765,  765,
      765,  403,  403,  403,  765,  403,  404,  765,  765,  765,
      765,  404,  404,  765,  404,  404,  765,  404,  404,  404,
      404,  404,  404,  404,  404,  404,  407,  765,  765,  407,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,

      407,  407,  407,  765,  407,  409,  409,  765,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  551,  551,  765,  551,  551,
      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  417,  765,  765,  765,  417,
      417,  417,  765,  417,  552,  552,  552,  765,  552,  420,
      420,  765,  765,  765,  420,  420,  420,  765,  420,  554,
      554,  765,  554,  554,  554,  554,  554,  554,  554,  554,
      554,  554,  554,  554,  554,  554,  554,  554,  554,  431,
      765,  765,  765,  765,  431,  431,  765,  431,  431,  431,

      431,  431,  431,  431,  431,  431,  431,  431,  431,  559,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  559,
      765,  765,  765,  559,  559,  559,  765,  559,  561,  561,
      765,  561,  561,  561,  561,  561,  561,  561,  561,  561,
      561,  561,  561,  561,  561,  561,  561,  561,  442,  442,
      765,  442,  442,  442,  442,  442,  442,  442,  442,  442,
      442,  442,  442,  442,  442,  442,  442,  442,  445,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  445,  445,  445,  765,  445,  564,  765,  765,
      765,  564,  564,  564,  765,  564,  448,  765,  765,  765,

      448,  448,  448,  765,  448,  452,  452,  765,  765,  452,
      452,  452,  765,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  765,  452,  457,  457,  765,  765,  457,
      457,  457,  765,  457,  457,  457,  457,  457,  457,  457,
      457,  457,  457,  765,  457,  574,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  574,
      574,  574,  765,  574,  468,  765,  765,  765,  765,  765,
      765,  765,  765,  468,  468,  765,  765,  765,  468,  468,
      468,  765,  468,  474,  765,  765,  765,  765,  765,  765,
      765,  474,  765,  474,  765,  765,  765,  474,  474,  474,

      765,  474,  578,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  578,  578,  578,  765,
      578,  480,  765,  765,  765,  765,  765,  765,  765,  765,
      480,  480,  765,  765,  765,  480,  480,  480,  765,  480,
      487,  765,  765,  765,  765,  765,  765,  765,  487,  765,
      487,  765,  487,  765,  487,  487,  487,  765,  487,  489,
      489,  765,  489,  489,  489,  489,  489,  489,  489,  489,
      489,  489,  489,  489,  489,  489,  489,  489,  489,  490,
      490,  765,  490,  490,  490,  490,  490,  490,  490,  490,
      490,  490,  490,  490,  490,  490,  490,  490,  490,  583,

      583,  583,  765,  583,  495,  765,  495,  495,  765,  765,
      765,  495,  495,  495,  765,  495,  499,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      499,  499,  499,  765,  499,  585,  765,  765,  765,  765,
      765,  765,  765,  585,  765,  585,  765,  585,  765,  585,
      585,  585,  765,  585,  319,  765,  765,  765,  765,  765,
      765,  765,  319,  765,  319,  765,  319,  765,  319,  319,
      319,  765,  319,  506,  765,  765,  765,  765,  765,  765,
      765,  506,  765,  506,  506,  506,  765,  506,  506,  506,
      765,  506,  337,  765,  765,  765,  765,  765,  765,  765,

      337,  765,  337,  337,  337,  765,  337,  337,  337,  765,
      337,  521,  521,  765,  521,  521,  521,  521,  521,  521,
      521,  521,  521,  521,  521,  521,  521,  521,  521,  521,
      521,  351,  351,  765,  765,  765,  351,  351,  351,  765,
      351,  527,  527,  765,  527,  527,  527,  527,  527,  527,
      527,  527,  527,  527,  527,  527,  527,  527,  527,  527,
      527,  368,  765,  765,  765,  368,  368,  368,  765,  368,
      544,  544,  765,  544,  544,  544,  544,  544,  544,  544,
      544,  544,  544,  544,  544,  544,  544,  544,  544,  544,
      551,  551,  765,  551,  551,  551,  551,  551,  551,  551,

      551,  551,  551,  551,  551,  551,  551,  551,  551,  551,
      629,  629,  765,  765,  765,  629,  629,  629,  765,  629,
      554,  554,  765,  554,  554,  554,  554,  554,  554,  554,
      554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
      632,  632,  632,  632,  765,  632,  632,  632,  632,  632,
      632,  632,  632,  632,  632,  632,  632,  632,  632,  632,
      559,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      559,  765,  765,  765,  559,  559,  559,  765,  559,  561,
      561,  765,  561,  561,  561,  561,  561,  561,  561,  561,
      561,  561,  561,  561,  561,  561,  561,  561,  561,  635,

      635,  765,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  564,
      765,  765,  765,  564,  564,  564,  765,  564,  574,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  574,  574,  574,  765,  574,  638,  765,  765,
      765,  765,  765,  765,  765,  765,  638,  638,  765,  765,
      765,  638,  638,  638,  765,  638,  468,  765,  765,  765,
      765,  765,  765,  765,  765,  468,  468,  765,  765,  765,
      468,  468,  468,  765,  468,  578,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  578,

      578,  578,  765,  578,  640,  765,  765,  765,  765,  765,
      765,  765,  765,  640,  640,  765,  765,  765,  640,  640,
      640,  765,  640,  643,  765,  643,  643,  765,  765,  765,
      643,  643,  643,  765,  643,  659,  659,  659,  765,  659,
      682,  765,  765,  765,  765,  765,  765,  765,  682,  765,
      682,  682,  682,  765,  682,  682,  682,  765,  682,  702,
      765,  702,  702,  765,  702,  765,  765,  765,  702,  702,
      702,  702,  702,  702,  702,  702,  702,  702,  709,  765,
      709,  709,  765,  709,  765,  765,  765,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  722,  722,  765,

      765,  722,  722,  722,  722,  722,  722,  722,  722,  722,
      722,  722,  722,  722,  722,  722,  722,  724,  765,  724,
      765,  765,  765,  765,  724,  724,  724,  724,  724,  724,
      724,  724,  724,  728,  728,  765,  765,  728,  728,  728,
      728,  728,  728,  728,  728,  728,  728,  728,  728,  728,
      728,  728,  728,  730,  765,  730,  765,  765,  765,  765,
      730,  730,  730,  730,  730,  730,  730,  730,  730,  741,
      765,  741,  765,  765,  765,  765,  741,  741,  741,  741,
      741,  741,  741,  741,  741,  743,  765,  743,  765,  765,
      765,  743,  743,  743,  743,  743,  743,  743,  743,  743,

      743,  746,  765,  746,  765,  765,  765,  765,  746,  746,
      746,  746,  746,  746,  746,  746,  746,  748,  765,  748,
      765,  765,  765,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  756,  765,  756,  765,  765,  765,  756,
      756,  756,  756,  756,  756,  756,  756,  756,  756,  758,
      765,  758,  765,  765,  765,  758,  758,  758,  758,  758,
      758,  758,  758,  758,  758,   59,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,

      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765
    } ;

static const flex_int16_t yy_chk[5631] =
    {   0,
        0,    0,    1,    2,   67,  107,   67,  107,    0,    1,
        2,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,

        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,

        5,    5,    5,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    9,    9,    9,
      738,    9,   10,   10,   10,    9,   10,   11,  737,   33,
       10,   11,   35,   33,   11,   12,   12,   12,  314,   35,
       12,  734,    9,   12,  314,   34,   36,   10,   33,   34,

       45,   11,   46,   36,  728,   47,    9,   45,   47,   46,
       12,   10,   47,   48,   34,   11,   48,   64,  722,   64,
       48,  132,   64,  132,   12,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,

       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   17,   17,   17,   39,   17,   17,   39,
      721,   17,   40,   39,   41,   40,  100,   41,   17,   40,
      100,   41,   42,  379,  118,   42,  379,   43,  118,   42,
       43,  163,  720,   44,   43,  163,   44,   17,  217,   17,
       44,  718,  217,   79,   39,  130,   57,   79,  382,   57,

       40,  382,   41,   57,   57,   57,  717,  714,   17,  130,
       42,   17,   18,   18,   18,   43,   18,   18,  698,  130,
       18,   44,   73,   79,   73,  525,  697,   18,  131,   57,
       58,   57,   73,   58,  145,   73,  145,   58,   58,   58,
      692,  148,  131,  148,   79,   73,   18,  154,   18,  154,
       57,   77,  131,   57,  134,   77,  134,  525,  676,  134,
      166,  166,  166,   58,  139,   58,  139,   18,   76,  139,
       18,   19,   76,  203,   19,  203,  495,  666,   19,   19,
       19,   77,  495,   19,   58,   78,   74,   58,   74,   78,
       74,   80,  665,   19,   74,   80,   74,   77,   76,   74,

      137,  664,   77,   75,  233,   75,  233,   75,   19,   74,
       19,   75,  663,   75,  137,   78,   75,  532,  227,   76,
       76,   80,  227,   82,  137,   82,   75,   78,   82,   86,
       19,   19,   20,   86,  532,   20,   78,   75,   80,   20,
       20,   20,   80,   83,   20,   83,  266,   88,  266,  662,
      159,   88,  159,   83,   20,  159,   83,  244,   75,   86,
       87,  244,  654,   83,   87,   82,   83,   82,   82,   20,
       82,   20,   82,  629,   84,   89,   84,   88,   84,   89,
       86,   86,   84,  273,   84,  273,  283,   84,  283,   88,
       87,   20,   20,   21,   84,   90,   21,   84,   88,   90,

       21,   21,   21,  138,  101,   89,   87,  388,  101,  104,
      388,   87,   21,  104,  211,  211,  211,  138,  220,  220,
      220,  230,  230,  230,  302,   90,   89,  138,  302,  318,
       21,  318,   21,  270,  101,  270,  120,  626,  625,  104,
      120,  114,   90,  114,  114,  114,   90,  113,  270,  113,
      113,  113,   21,   21,   22,  101,  624,   22,  114,  114,
      104,   22,   22,   22,  113,  113,  120,  354,  123,  113,
      164,  354,  123,   22,  164,  141,  114,  141,  317,  165,
      317,  218,  113,  165,  141,  218,  219,  120,  317,  619,
      219,   22,  305,   22,  305,  141,  583,  305,  123,  228,

      164,  317,  583,  228,  229,  271,  245,  271,  229,  165,
      245,  218,  618,   22,   22,   23,  219,  612,   23,  123,
      271,  164,   23,   23,   23,  598,  339,   23,  339,  228,
      165,  246,  218,  597,  229,  246,  245,  219,  250,  250,
      250,  254,  254,  254,  281,  281,  281,  643,  580,  280,
      228,  280,   23,  643,   23,  229,  271,  245,  286,  280,
      286,  246,  280,  303,  358,  304,  358,  303,  307,  304,
      307,  315,  579,  286,   23,   23,   24,  315,  307,   24,
      339,  307,  246,   24,   24,   24,  373,  316,   24,  316,
      373,  307,  764,  303,  319,  304,  319,  316,  764,  668,

      316,  363,  363,  363,  319,  668,  383,  319,  383,  389,
      316,  566,  389,   24,  303,   24,  304,  319,  385,  315,
      385,  413,  390,  385,  390,  413,  395,  390,  395,  397,
      399,  397,  399,  565,  668,   24,   24,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,

       25,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   29,   29,   29,   29,  562,
       29,   29,  560,  323,   29,  323,  402,  323,  402,  556,
      324,  323,  324,  323,  429,  555,  323,  405,  429,  405,
      324,   29,  405,  324,  439,  325,  323,  325,  439,  326,

       29,  326,   29,  324,  418,  325,  418,  451,  325,  326,
      553,  451,  326,  414,  414,  414,  486,  433,  325,  433,
      486,   29,  326,  644,   29,   30,   30,   30,   30,  644,
       30,   30,  840,  329,   30,  329,  840,  325,  329,  324,
      552,  550,  327,  328,  327,  328,  326,  444,  330,  444,
      330,   30,  327,  328,  549,  327,  328,  465,  330,  465,
       30,  330,   30,  644,  716,  327,  328,  467,  330,  467,
      716,  330,  421,  421,  421,  329,  543,  329,  329,  723,
      329,   30,  329,  723,   30,   31,   31,   31,  729,   31,
       31,  542,  729,   31,  331,  327,  331,  328,  430,  430,

      430,  716,  723,  332,  331,  332,  496,  331,  440,  440,
      440,  729,  496,  332,  331,  541,  332,  331,  333,   31,
      333,   31,  466,  332,  466,  539,  332,  393,  333,  393,
      538,  333,  455,  455,  455,  534,  393,  466,  333,  496,
       31,  333,  533,   31,   32,   32,   32,  393,   32,   32,
      331,  529,   32,  332,  526,  468,  336,  468,  336,  524,
      470,  337,  470,  337,  333,  473,  336,  473,  523,  336,
      468,  337,  520,  477,  337,  477,  336,  514,   32,  336,
       32,  337,  492,  488,  337,  460,  460,  460,  471,  485,
      471,  475,  475,  475,  479,  498,  479,  498,  471,   32,

      484,  471,   32,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,

       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,
       49,   51,   51,   51,   51,   51,   51,   51,   51,   51,
       51,   51,   51,   51,   51,   51,   51,   51,   51,   51,
       51,   51,   51,   51,   51,   51,   51,   51,   51,   51,
       51,   51,   51,   51,   51,   51,   51,   51,   51,   51,
       51,   51,   51,   51,   51,   51,   51,   51,   51,   51,
       51,   51,   51,   51,   51,   51,   51,   51,   51,   51,
       51,   51,   51,   51,   51,   53,   53,   53,   53,   53,

       53,   53,   53,   53,   53,   53,   53,   53,   53,   53,
       53,   53,   53,   53,   53,   53,   53,   53,   53,   53,
       53,   53,   53,   53,   53,   53,   53,   53,   53,   53,
       53,   53,   53,   53,   53,   53,   53,   53,   53,   53,
       53,   53,   53,   53,   53,   53,   53,   53,   53,   53,
       53,   53,   53,   53,   53,   53,   53,   53,   53,   55,
      483,  482,   55,  335,  763,  335,   55,   55,   55,  334,
      763,  334,  478,  335,  478,  474,  335,  474,   55,  334,
      463,   55,  334,  335,  462,  474,  335,  478,  474,  334,
      458,  364,  334,  364,  364,  364,   55,   55,   55,  453,

      763,  469,  340,  469,  340,  558,  340,  558,  364,  364,
      340,  513,  340,  513,  335,  340,  469,  450,   55,   55,
       56,  449,  340,   56,  334,  340,  364,   56,   56,   56,
      342,  341,  342,  341,  480,  559,  480,  559,  447,   56,
      342,  341,   56,  342,  341,  497,  573,  497,  573,  480,
      342,  341,  446,  342,  341,  469,  443,   56,   56,   56,
      568,  568,  568,  438,  343,  513,  343,  437,  497,  570,
      570,  570,  342,  576,  343,  576,  577,  343,  577,   56,
       56,   85,  436,   85,  343,   85,  344,  343,  344,   85,
      341,   85,  434,  432,   85,  487,  344,  487,  574,  344,

      574,   85,  428,  427,   85,  487,  344,  426,  487,  344,
      345,  343,  345,  574,  725,   85,  725,  425,  487,  499,
      345,  499,  731,  345,  731,  584,  660,  660,  660,  499,
      345,  584,  499,  345,  423,  420,   85,  105,  105,  344,
      105,  105,  499,  412,  105,  105,  411,  105,  105,  105,
      105,  105,  105,  410,  105,  105,  105,  105,  105,  105,
      105,  408,  105,  105,  345,  578,  406,  578,  365,  735,
      365,  365,  365,  584,  401,  735,  105,  105,  105,  392,
      578,  530,  530,  530,  391,  365,  365,  377,  686,  691,
      686,  596,  530,  596,  376,  691,  530,  372,  105,  105,

      105,  357,  357,  365,  357,  357,  686,  686,  357,  357,
      530,  357,  357,  357,  357,  357,  357,  735,  357,  357,
      357,  357,  357,  357,  357,  371,  357,  357,  370,  369,
      688,  691,  688,  503,  506,  503,  506,  638,  362,  638,
      357,  357,  357,  503,  506,  596,  503,  506,  688,  688,
      359,  356,  638,  609,  506,  609,  503,  506,  609,  609,
      609,  355,  357,  357,  357,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,

      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  353,  501,  407,  501,
      352,  502,  504,  502,  504,  350,  505,  501,  505,  347,
      501,  502,  504,  322,  502,  504,  505,  321,  313,  505,
      501,  507,  309,  507,  502,  504,  308,  761,  640,  505,
      640,  507,  306,  761,  507,  508,  690,  508,  690,  299,
      736,  507,  736,  640,  507,  508,  298,  295,  508,  501,
      509,  690,  509,  504,  575,  508,  575,  502,  508,  505,
      509,  258,  510,  509,  510,  739,  511,  739,  511,  575,

      509,  761,  510,  509,  257,  510,  511,  508,  751,  511,
      507,  515,  510,  515,  751,  510,  511,  253,  248,  511,
      516,  515,  516,  639,  515,  639,  517,  509,  517,  240,
      516,  515,  239,  516,  515,  232,  517,  575,  639,  517,
      516,  226,  518,  516,  518,  510,  517,  751,  224,  517,
      511,  519,  518,  519,  223,  518,  585,  586,  585,  586,
      216,  519,  518,  515,  519,  518,  585,  586,  215,  585,
      586,  519,  214,  588,  519,  588,  516,  208,  639,  585,
      586,  167,  715,  588,  715,  162,  588,  661,  661,  661,
      750,  160,  750,  518,  152,  144,  588,  715,  752,  140,

      752,  586,  661,  129,  519,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  540,
      540,  540,  540,  540,  540,  540,  540,  540,  540,  540,
      540,  540,  540,  540,  540,  540,  540,  540,  540,  540,
      540,  540,  540,  540,  540,  540,  540,  540,  540,  540,

      540,  540,  540,  540,  540,  540,  540,  540,  540,  540,
      540,  540,  540,  540,  540,  540,  540,  540,  540,  540,
      540,  540,  540,  540,  540,  540,  540,  540,  540,  540,
      540,  540,  540,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  128,  587,  547,  587,  122,  589,

      590,  589,  590,  119,  591,  587,  591,  117,  587,  589,
      590,  111,  589,  590,  591,  110,  109,  591,  587,  592,
      103,  592,  589,  590,  591,  102,   96,  591,  667,  592,
      667,  753,  592,  753,  593,  755,  593,  755,  760,  592,
      760,   95,  592,  667,  593,   94,   72,  593,  594,   68,
      594,  587,   66,   65,  593,  590,  591,  593,  594,   59,
      595,  594,  595,  705,  599,  705,  599,  762,  594,  762,
      595,  594,  884,  595,  599,  592,  884,  599,  884,    0,
      595,  705,  705,  595,  599,  667,    0,  599,    0,    0,
        0,  600,  601,  600,  601,    0,  602,    0,  602,  594,

        0,  600,  601,    0,  600,  601,  602,    0,  599,  602,
        0,  600,  601,  595,  600,  601,  602,    0,  603,  602,
      603,    0,  645,  646,  645,  646,    0,  647,  603,  647,
        0,  603,  645,  646,    0,  645,  646,  647,  603,    0,
      647,  603,  689,    0,  689,  645,  646,  600,    0,  648,
      647,  648,  712,    0,  712,  651,  652,  651,  652,  648,
      689,  689,  648,    0,    0,  651,  652,    0,  651,  652,
      712,  712,  648,  603,  616,  651,  652,    0,  651,  652,
        0,    0,    0,  724,  724,  689,    0,    0,  724,    0,
        0,    0,    0,    0,  616,  616,  616,  616,  616,  616,

      616,  616,  616,  616,  616,  616,  648,  724,    0,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  622,    0,
        0,    0,    0,    0,    0,    0,  730,  730,  741,  741,
        0,  730,    0,  741,    0,    0,    0,    0,  622,  622,
      622,  622,  622,  622,  622,  622,  622,  622,  622,  622,
      730,    0,  741,  622,  622,  622,  622,  622,  622,  622,
      622,  622,  622,  622,  622,  622,  622,  622,  622,  622,
      622,  622,  649,  650,  649,  650,    0,  653,  655,  653,
      655,    0,  649,  650,    0,  649,  650,  653,  655,    0,

      653,  655,  649,  650,    0,  649,  650,  653,  655,    0,
      653,  655,  656,    0,  656,    0,    0,  657,  658,  657,
      658,    0,  656,    0,    0,  656,  649,  657,  658,    0,
      657,  658,  656,    0,  659,  656,  659,  657,  658,  650,
      657,  658,  653,  669,  659,  669,    0,  659,  670,  671,
      670,  671,    0,  669,  659,    0,  669,  659,  670,  671,
        0,  670,  671,  672,    0,  672,  669,  673,    0,  673,
        0,  670,  671,  672,    0,  658,  672,  673,    0,  674,
      673,  674,    0,  672,    0,    0,  672,  673,  669,  674,
      673,  675,  674,  675,    0,  677,  678,  677,  678,  674,

        0,  675,  674,    0,  675,  677,  678,    0,  677,  678,
      679,  675,  679,    0,  675,  677,  678,    0,  677,  678,
      679,    0,  680,  679,  680,    0,  682,    0,  682,    0,
      679,    0,  680,  679,    0,  680,  682,    0,    0,  682,
      677,    0,  680,    0,    0,  680,  682,    0,  675,  682,
      685,    0,  685,  687,  685,  687,    0,  687,    0,    0,
        0,  693,  694,  693,  694,  685,  685,    0,  687,  687,
      685,  693,  694,  687,  693,  694,    0,  695,  696,  695,
      696,    0,  694,    0,  693,  694,    0,  695,  696,  685,
      695,  696,  687,  699,    0,  699,    0,  695,  696,    0,

      695,  696,    0,  699,    0,    0,  699,  694,  700,    0,
      700,    0,  700,  699,    0,  702,  699,  702,  704,  702,
      704,    0,  704,  700,  700,  706,  706,  706,  700,    0,
      702,  702,    0,  704,  704,  702,    0,    0,  704,    0,
      706,    0,  706,  706,  706,    0,  707,  700,  707,  709,
      707,  709,    0,  709,  702,    0,  711,  704,  711,    0,
      711,  707,  707,    0,  709,  709,  707,    0,    0,  709,
        0,  711,  711,    0,    0,    0,  711,  742,  742,  713,
      713,  713,  742,    0,    0,  707,    0,    0,  709,  719,
        0,  719,    0,    0,  713,  711,  713,  713,  713,  719,

        0,  742,  719,  727,  727,  727,    0,    0,    0,  719,
        0,    0,  719,  733,  733,  733,    0,    0,  727,    0,
      727,  727,  727,    0,  743,  743,    0,    0,  733,  743,
      733,  733,  733,  744,  744,  746,  746,    0,  744,    0,
      746,  747,  747,    0,  748,  748,  747,    0,  743,  748,
      749,  749,    0,  756,  756,  749,    0,  744,  756,  746,
        0,  757,  757,    0,    0,  747,  757,    0,  748,    0,
      758,  758,    0,    0,  749,  758,    0,  756,  759,  759,
        0,    0,    0,  759,    0,  757,    0,    0,    0,    0,
        0,    0,    0,    0,  758,    0,    0,    0,    0,    0,

        0,    0,  759,  766,  766,  766,  766,  766,  766,  766,
      766,  766,  766,  766,  766,  766,  766,  766,  766,  766,
      766,  766,  766,  767,  767,  767,  767,  767,  767,  767,
      767,  767,  767,  767,  767,  767,  767,  767,  767,  767,
      767,  767,  767,  768,  768,  768,  768,  768,  768,  768,
      768,  768,  768,  768,  768,  768,  768,  768,  768,  768,
      768,  768,  768,  769,  769,  769,  769,  769,  769,  769,
      769,  769,  769,  769,  769,  769,  769,  769,  769,  769,
      769,  769,  769,  770,  770,  770,  770,  770,  770,  770,
      770,  770,  770,  770,  770,  770,  770,  770,  770,  770,

      770,  770,  770,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  773,  773,  773,  773,  773,  773,  773,
      773,  773,  773,  773,  773,  773,  773,  773,  773,  773,
      773,  773,  773,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  775,  775,  775,  775,  775,  775,  775,
      775,  775,  775,  775,  775,  775,  775,  775,  775,  775,

      775,  775,  775,  776,  776,  776,  776,  776,  776,  776,
      776,  776,  776,  776,  776,  776,  776,  776,  776,  776,
      776,  776,  776,  777,  777,  777,  777,  777,  777,  777,
      777,  777,  777,  777,  777,  777,  777,  777,  777,  777,
      777,  777,  777,  778,  778,  778,  778,  778,  778,  778,
      778,  778,  778,  778,  778,  778,  778,  778,  778,  778,
      778,  778,  778,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  779,  779,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  780,

      780,  780,  780,  781,  781,  781,  781,  781,  781,  781,
      781,  781,  781,  781,  781,  781,  781,  781,  781,  781,
      781,  781,  781,  782,  782,  782,  782,  782,  782,  782,
      782,  782,  782,  782,  782,  782,  782,  782,  782,  782,
      782,  782,  782,  783,    0,    0,  783,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  783,  783,  783,
        0,  783,  784,  784,    0,  784,  784,  784,  784,  784,
      784,  784,  784,  784,  784,  784,  784,  784,  784,  784,
      784,  784,  785,  785,  785,    0,  785,  786,    0,    0,
        0,    0,    0,    0,    0,  786,    0,  786,    0,  786,

        0,  786,  786,  786,    0,  786,  787,    0,    0,  787,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      787,  787,  787,    0,  787,  788,    0,    0,    0,    0,
        0,    0,    0,  788,    0,  788,  788,  788,    0,  788,
      788,  788,    0,  788,  789,  789,    0,    0,    0,  789,
      789,    0,  789,  789,    0,  789,  789,    0,  789,    0,
        0,    0,  789,  789,  790,  790,    0,  790,  790,  790,
      790,  790,  790,  790,  790,  790,  790,  790,  790,  790,
      790,  790,  790,  790,  791,    0,    0,    0,  791,  791,
      791,    0,  791,  792,  792,    0,  792,  792,  792,  792,

      792,  792,  792,  792,  792,  792,  792,  792,  792,  792,
      792,  792,  792,  793,    0,    0,    0,  793,  793,  793,
        0,  793,  794,    0,    0,    0,  794,  794,  794,    0,
      794,  794,  794,  794,  794,  794,    0,  794,  794,  794,
        0,  794,  795,  795,    0,  795,  795,  795,  795,  795,
      795,  795,  795,  795,  795,  795,  795,  795,  795,  795,
      795,  795,  796,  796,    0,  796,    0,  796,  796,  796,
      796,  796,  796,  796,  796,  796,    0,  796,  796,  796,
        0,  796,  797,    0,    0,    0,  797,  797,  797,    0,
      797,  798,  798,    0,  798,    0,  798,  798,  798,  798,

      798,  798,  798,  798,  798,  798,  798,  798,  798,  798,
      798,  799,    0,    0,    0,  799,  799,  799,    0,  799,
      800,    0,    0,    0,    0,  800,  800,    0,  800,  800,
        0,  800,  800,  800,  800,  800,  800,  800,  800,  800,
      801,    0,    0,  801,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  801,  801,  801,    0,  801,  802,
      802,    0,  802,  802,  802,  802,  802,  802,  802,  802,
      802,  802,  802,  802,  802,  802,  802,  802,  802,  803,
      803,    0,  803,  803,  803,  803,  803,  803,  803,  803,
      803,  803,  803,  803,  803,  803,  803,  803,  803,  804,

        0,    0,    0,  804,  804,  804,    0,  804,  805,  805,
        0,    0,    0,  805,  805,  805,    0,  805,  806,  806,
        0,  806,  806,  806,  806,  806,  806,  806,  806,  806,
      806,  806,  806,  806,  806,  806,  806,  806,  807,    0,
        0,    0,    0,  807,  807,    0,  807,  807,  807,  807,
      807,  807,  807,  807,  807,  807,  807,  807,  808,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  808,
      808,  808,    0,  808,  809,  809,    0,  809,    0,  809,
      809,  809,  809,  809,  809,  809,  809,  809,  809,  809,
      809,  809,  809,  809,  810,  810,    0,  810,  810,  810,

      810,  810,  810,  810,  810,  810,  810,  810,  810,  810,
      810,  810,  810,  810,  811,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  811,  811,
      811,    0,  811,  812,    0,    0,    0,  812,  812,  812,
        0,  812,  813,  813,    0,    0,  813,  813,  813,    0,
      813,  813,  813,  813,  813,  813,  813,  813,  813,  813,
        0,  813,  814,  814,  814,  814,  814,  814,  814,  814,
      814,  814,  814,  814,  814,  814,  814,  814,  814,  814,
      814,  814,  815,  815,    0,    0,  815,  815,  815,    0,
      815,  815,  815,  815,  815,  815,  815,  815,  815,  815,

        0,  815,  816,  816,  816,  816,  816,  816,  816,  816,
      816,  816,  816,  816,  816,  816,  816,  816,  816,  816,
      816,  816,  817,  817,    0,  817,  817,  817,  817,  817,
      817,  817,  817,  817,  817,  817,  817,  817,  817,  817,
      817,  817,  818,    0,    0,    0,    0,    0,    0,    0,
        0,  818,  818,    0,    0,    0,  818,  818,  818,    0,
      818,  819,    0,    0,    0,    0,    0,    0,    0,  819,
        0,  819,    0,    0,    0,  819,  819,  819,    0,  819,
      820,    0,    0,    0,    0,    0,    0,    0,    0,  820,
      820,    0,    0,    0,  820,  820,  820,    0,  820,  821,

        0,    0,  821,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  821,  821,  821,    0,  821,  822,    0,
        0,    0,    0,    0,    0,    0,  822,    0,  822,    0,
      822,    0,  822,  822,  822,    0,  822,  823,  823,    0,
      823,  823,  823,  823,  823,  823,  823,  823,  823,  823,
      823,  823,  823,  823,  823,  823,  823,  824,  824,    0,
      824,  824,  824,  824,  824,  824,  824,  824,  824,  824,
      824,  824,  824,  824,  824,  824,  824,  825,  825,  825,
      825,    0,  825,  825,  825,  825,  825,  825,  825,  825,
      825,  825,  825,  825,  825,  825,  825,  826,    0,  826,

      826,    0,    0,    0,  826,  826,  826,    0,  826,  827,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  827,  827,  827,    0,  827,  828,    0,
        0,    0,    0,    0,    0,    0,  828,    0,  828,    0,
      828,    0,  828,  828,  828,    0,  828,  829,  829,  829,
      829,  829,  829,  829,  829,  829,  829,  829,  829,  829,
        0,  829,  829,  829,  829,  829,  829,  830,    0,    0,
      830,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  830,  830,  830,    0,  830,  831,    0,    0,    0,
        0,    0,    0,    0,  831,    0,  831,  831,  831,    0,

      831,  831,  831,    0,  831,  832,    0,    0,    0,    0,
        0,    0,    0,  832,    0,  832,  832,  832,    0,  832,
      832,  832,    0,  832,  833,  833,  833,  833,  833,  833,
      833,  833,  833,  833,  833,  833,  833,    0,  833,  833,
      833,  833,  833,  833,  834,  834,    0,    0,    0,  834,
      834,    0,  834,  834,    0,  834,  834,    0,  834,    0,
        0,    0,  834,  834,  835,  835,    0,  835,  835,  835,
      835,  835,  835,  835,  835,  835,  835,  835,  835,  835,
      835,  835,  835,  835,  836,  836,  836,  836,    0,  836,
      836,  836,  836,  836,  836,  836,  836,  836,  836,  836,

      836,  836,  836,  836,  837,    0,    0,    0,  837,  837,
      837,    0,  837,  838,  838,    0,  838,  838,  838,  838,
      838,  838,  838,  838,  838,  838,  838,  838,  838,  838,
      838,  838,  838,  839,  839,  839,  839,    0,  839,  839,
      839,  839,  839,  839,  839,  839,  839,  839,  839,  839,
      839,  839,  839,  841,    0,    0,    0,  841,  841,  841,
        0,  841,  842,    0,    0,    0,  842,  842,  842,    0,
      842,  842,  842,  842,  842,  842,    0,  842,  842,  842,
        0,  842,  843,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  843,  843,  843,  844,  844,    0,  844,    0,

      844,  844,  844,  844,  844,  844,  844,  844,  844,    0,
      844,  844,  844,    0,  844,  845,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  845,  845,  845,  846,    0,
        0,    0,  846,  846,  846,    0,  846,  847,  847,    0,
      847,  847,  847,  847,  847,  847,  847,  847,  847,  847,
      847,  847,  847,  847,  847,  847,  847,  848,    0,    0,
        0,  848,  848,  848,    0,  848,  849,    0,    0,    0,
        0,  849,  849,    0,  849,  849,    0,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  850,    0,    0,  850,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

      850,  850,  850,    0,  850,  851,  851,    0,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  852,  852,    0,  852,  852,
      852,  852,  852,  852,  852,  852,  852,  852,  852,  852,
      852,  852,  852,  852,  852,  853,    0,    0,    0,  853,
      853,  853,    0,  853,  854,  854,  854,    0,  854,  855,
      855,    0,    0,    0,  855,  855,  855,    0,  855,  856,
      856,    0,  856,  856,  856,  856,  856,  856,  856,  856,
      856,  856,  856,  856,  856,  856,  856,  856,  856,  857,
        0,    0,    0,    0,  857,  857,    0,  857,  857,  857,

      857,  857,  857,  857,  857,  857,  857,  857,  857,  858,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  858,
        0,    0,    0,  858,  858,  858,    0,  858,  859,  859,
        0,  859,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859,  859,  859,  859,  859,  859,  859,  860,  860,
        0,  860,  860,  860,  860,  860,  860,  860,  860,  860,
      860,  860,  860,  860,  860,  860,  860,  860,  861,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  861,  861,  861,    0,  861,  862,    0,    0,
        0,  862,  862,  862,    0,  862,  863,    0,    0,    0,

      863,  863,  863,    0,  863,  864,  864,    0,    0,  864,
      864,  864,    0,  864,  864,  864,  864,  864,  864,  864,
      864,  864,  864,    0,  864,  865,  865,    0,    0,  865,
      865,  865,    0,  865,  865,  865,  865,  865,  865,  865,
      865,  865,  865,    0,  865,  866,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  866,
      866,  866,    0,  866,  867,    0,    0,    0,    0,    0,
        0,    0,    0,  867,  867,    0,    0,    0,  867,  867,
      867,    0,  867,  868,    0,    0,    0,    0,    0,    0,
        0,  868,    0,  868,    0,    0,    0,  868,  868,  868,

        0,  868,  869,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  869,  869,  869,    0,
      869,  870,    0,    0,    0,    0,    0,    0,    0,    0,
      870,  870,    0,    0,    0,  870,  870,  870,    0,  870,
      871,    0,    0,    0,    0,    0,    0,    0,  871,    0,
      871,    0,  871,    0,  871,  871,  871,    0,  871,  872,
      872,    0,  872,  872,  872,  872,  872,  872,  872,  872,
      872,  872,  872,  872,  872,  872,  872,  872,  872,  873,
      873,    0,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  874,

      874,  874,    0,  874,  875,    0,  875,  875,    0,    0,
        0,  875,  875,  875,    0,  875,  876,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      876,  876,  876,    0,  876,  877,    0,    0,    0,    0,
        0,    0,    0,  877,    0,  877,    0,  877,    0,  877,
      877,  877,    0,  877,  878,    0,    0,    0,    0,    0,
        0,    0,  878,    0,  878,    0,  878,    0,  878,  878,
      878,    0,  878,  879,    0,    0,    0,    0,    0,    0,
        0,  879,    0,  879,  879,  879,    0,  879,  879,  879,
        0,  879,  880,    0,    0,    0,    0,    0,    0,    0,

      880,    0,  880,  880,  880,    0,  880,  880,  880,    0,
      880,  881,  881,    0,  881,  881,  881,  881,  881,  881,
      881,  881,  881,  881,  881,  881,  881,  881,  881,  881,
      881,  882,  882,    0,    0,    0,  882,  882,  882,    0,
      882,  883,  883,    0,  883,  883,  883,  883,  883,  883,
      883,  883,  883,  883,  883,  883,  883,  883,  883,  883,
      883,  885,    0,    0,    0,  885,  885,  885,    0,  885,
      886,  886,    0,  886,  886,  886,  886,  886,  886,  886,
      886,  886,  886,  886,  886,  886,  886,  886,  886,  886,
      887,  887,    0,  887,  887,  887,  887,  887,  887,  887,

      887,  887,  887,  887,  887,  887,  887,  887,  887,  887,
      888,  888,    0,    0,    0,  888,  888,  888,    0,  888,
      889,  889,    0,  889,  889,  889,  889,  889,  889,  889,
      889,  889,  889,  889,  889,  889,  889,  889,  889,  889,
      890,  890,  890,  890,    0,  890,  890,  890,  890,  890,
      890,  890,  890,  890,  890,  890,  890,  890,  890,  890,
      891,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      891,    0,    0,    0,  891,  891,  891,    0,  891,  892,
      892,    0,  892,  892,  892,  892,  892,  892,  892,  892,
      892,  892,  892,  892,  892,  892,  892,  892,  892,  893,

      893,    0,  893,  893,  893,  893,  893,  893,  893,  893,
      893,  893,  893,  893,  893,  893,  893,  893,  893,  894,
        0,    0,    0,  894,  894,  894,    0,  894,  895,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  895,  895,  895,    0,  895,  896,    0,    0,
        0,    0,    0,    0,    0,    0,  896,  896,    0,    0,
        0,  896,  896,  896,    0,  896,  897,    0,    0,    0,
        0,    0,    0,    0,    0,  897,  897,    0,    0,    0,
      897,  897,  897,    0,  897,  898,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  898,

      898,  898,    0,  898,  899,    0,    0,    0,    0,    0,
        0,    0,    0,  899,  899,    0,    0,    0,  899,  899,
      899,    0,  899,  900,    0,  900,  900,    0,    0,    0,
      900,  900,  900,    0,  900,  901,  901,  901,    0,  901,
      902,    0,    0,    0,    0,    0,    0,    0,  902,    0,
      902,  902,  902,    0,  902,  902,  902,    0,  902,  903,
        0,  903,  903,    0,  903,    0,    0,    0,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  904,    0,
      904,  904,    0,  904,    0,    0,    0,  904,  904,  904,
      904,  904,  904,  904,  904,  904,  904,  905,  905,    0,

        0,  905,  905,  905,  905,  905,  905,  905,  905,  905,
      905,  905,  905,  905,  905,  905,  905,  906,    0,  906,
        0,    0,    0,    0,  906,  906,  906,  906,  906,  906,
      906,  906,  906,  907,  907,    0,    0,  907,  907,  907,
      907,  907,  907,  907,  907,  907,  907,  907,  907,  907,
      907,  907,  907,  908,    0,  908,    0,    0,    0,    0,
      908,  908,  908,  908,  908,  908,  908,  908,  908,  909,
        0,  909,    0,    0,    0,    0,  909,  909,  909,  909,
      909,  909,  909,  909,  909,  910,    0,  910,    0,    0,
        0,  910,  910,  910,  910,  910,  910,  910,  910,  910,

      910,  911,    0,  911,    0,    0,    0,    0,  911,  911,
      911,  911,  911,  911,  911,  911,  911,  912,    0,  912,
        0,    0,    0,  912,  912,  912,  912,  912,  912,  912,
      912,  912,  912,  913,    0,  913,    0,    0,    0,  913,
      913,  913,  913,  913,  913,  913,  913,  913,  913,  914,
        0,  914,    0,    0,    0,  914,  914,  914,  914,  914,
      914,  914,  914,  914,  914,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,

      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765
    } ;

#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */ \
yy_cp = yyg->yy_full_match; /* restore poss. backed-over text */ \
yyg->yy_lp = yyg->yy_full_lp; /* restore orig. accepting pos. */ \
yyg->yy_state_ptr = yyg->yy_full_state; /* restore orig. state */ \
yy_current_state = *yyg->yy_state_ptr; /* restore curr. state */ \
++yyg->yy_lp; \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "/build/doxygen/src/build/generated_src/pyscanner.l"
/******************************************************************************
 *
 * Copyright (C) 1997-2021 by Dimitri van Heesch.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation under the terms of the GNU General Public License is hereby
 * granted. No representations are made about the suitability of this software
 * for any purpose. It is provided "as is" without express or implied warranty.
 * See the GNU General Public License for more details.
 *
 * Documents produced by Doxygen are derivative works derived from the
 * input used in their production; they are not affected by this license.
 *
 */
/*  This code is based on the work done by the MoxyPyDoxy team
 *  (Linda Leong, Mike Rivera, Kim Truong, and Gabriel Estrada)
 *  in Spring 2005 as part of CS 179E: Compiler Design Project
 *  at the University of California, Riverside; the course was
 *  taught by Peter H. Froehlich <phf@acm.org>.
 */

#line 35 "/build/doxygen/src/build/generated_src/pyscanner.l"

/*
 *      includes
 */

#include <algorithm>

#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include <ctype.h>
#include <string.h>

#include "pyscanner.h"
#include "entry.h"
#include "message.h"
#include "config.h"
#include "doxygen.h"
#include "util.h"
#include "defargs.h"
#include "language.h"
#include "commentscan.h"
#include "arguments.h"
#include "markdown.h"
#include "fileinfo.h"
#include "debug.h"
#include "stringutil.h"

// Toggle for some debugging info
//#define DBG_CTX(x) fprintf x
#define DBG_CTX(x) do { } while(0)

#define YY_NO_INPUT 1
#define YY_NO_UNISTD_H 1

#define unput_string(yytext,yyleng) do { for (int i=(int)yyleng-1;i>=0;i--) unput(yytext[i]); } while(0)

/* ----------------------------------------------------------------- */

struct pyscannerYY_state
{
  CommentScanner          commentScanner;
  OutlineParserInterface *thisParser = nullptr;
  const char *            inputString = nullptr;
  int                     inputPosition = 0;
  Protection              protection = Protection::Public;
  std::shared_ptr<Entry>  current_root;
  std::shared_ptr<Entry>  current;
  std::shared_ptr<Entry>  previous;
  std::shared_ptr<Entry>  bodyEntry;
  int                     yyLineNr = 1 ;
  QCString                fileName;
  MethodTypes             mtype = MethodTypes::Method;
  bool                    isStatic = FALSE;
  Specifier               virt = Specifier::Normal;
  int                     docBlockContext = 0;
  QCString                docBlock;
  bool                    docBlockInBody = FALSE;
  bool                    docBlockJavaStyle = FALSE;
  bool                    docBrief = FALSE;
  bool                    docBlockSpecial = FALSE;
  bool                    doubleQuote = FALSE;
  bool                    specialBlock = FALSE;
  int                     stringContext = 0;
  TextStream *            copyString = nullptr;
  int                     indent = 0;
  int                     curIndent = 0;
  int                     commentIndent = 0;
  bool                    importTuple = FALSE;
  StringUnorderedMap      packageNameCache;
  char                    atomStart = 0;
  char                    atomEnd = 0;
  int                     atomCount = 0;
  int                     atomContext = 0;
  QCString                moduleScope;
  QCString                packageName;
  TextStream              defVal;
  int                     braceCount = 0;
  bool                    lexInit = FALSE;
  bool                    packageCommentAllowed = FALSE;
  bool                    startInit = FALSE;
  int                     searchCount = 0;
  QCString                argType;
  bool                    funcParamsEnd = FALSE;
  std::vector<QCString>   decorators;
  QCString                programStr;
  TextStream              decoratorCommentStr;
  int                     decoratorRound = 0;
  bool                    checkDupEntry = false;
  bool                    firstPass = true;
  int                     bracketDepth = 0;
};

//-----------------------------------------------------------------------------
[[maybe_unused]] static const char *stateToString(int state);

static inline int computeIndent(const char *s);

static void initParser(yyscan_t yyscanner);
static void initEntry(yyscan_t yyscanner);
static void newEntry(yyscan_t yyscanner);
static void addEntry(yyscan_t yyscanner);
static void docVariable(yyscan_t yyscanner,const char *s);
static void newVariable(yyscan_t yyscanner);
static void addVariable(yyscan_t yyscanner);
static void newFunction(yyscan_t yyscanner);
static QCString findPackageScopeFromPath(yyscan_t yyscanner,const QCString &path);
static void addFrom(yyscan_t yyscanner,bool all);
static void lineCount(yyscan_t yyscanner);
static void incLineNr(yyscan_t yyscanner);
static void startCommentBlock(yyscan_t yyscanner,bool brief);
static void handleCommentBlock(yyscan_t yyscanner,const QCString &doc,bool brief);
static void endOfDef(yyscan_t yyscanner,int correction=0);
static inline void addToString(yyscan_t yyscanner,const char *s);
static void initTriDoubleQuoteBlock(yyscan_t yyscanner);
static void initTriSingleQuoteBlock(yyscan_t yyscanner);
static void initSpecialBlock(yyscan_t yyscanner);
static void searchFoundDef(yyscan_t yyscanner);
static void searchFoundClass(yyscan_t yyscanner);
static QCString findPackageScope(yyscan_t yyscanner,const QCString &fileName);
static void setProtection(yyscan_t yyscanner);

static int yyread(yyscan_t yyscanner,char *buf,int max_size);

//-----------------------------------------------------------------------------
/* ----------------------------------------------------------------- */
#undef  YY_INPUT
#define YY_INPUT(buf,result,max_size) result=yyread(yyscanner,buf,max_size);

// otherwise the filename would be the name of the converted file (*.cpp instead of *.l)
static inline const char *getLexerFILE() {return __FILE__;}
#include "doxygen_lex.h"

#line 2497 "/build/doxygen/src/build/generated_src/pyscanner_intermediate.cpp"
#line 171 "/build/doxygen/src/build/generated_src/pyscanner.l"
       /* start command character */
  /* Main start state */



  /* Mid-comment states */
  /* %x FuncDoubleComment */
  /* %x ClassDoubleComment */


  /* Function states */






  /* Class states */




  /* Variable states */



  /* String states */





  /* import */



  /* TypeHints */

  /* Decorator */

#line 2539 "/build/doxygen/src/build/generated_src/pyscanner_intermediate.cpp"

#define INITIAL 0
#define Search 1
#define SearchMemVars 2
#define SearchSkipValue 3
#define TripleComment 4
#define SpecialComment 5
#define FunctionDec 6
#define FunctionParams 7
#define FunctionBody 8
#define FunctionAnnotation 9
#define FunctionTypeAnnotation 10
#define FunctionParamDefVal 11
#define ClassDec 12
#define ClassInheritance 13
#define ClassCaptureIndent 14
#define ClassBody 15
#define VariableDec 16
#define VariableEnd 17
#define VariableAtom 18
#define SingleQuoteString 19
#define DoubleQuoteString 20
#define TripleString 21
#define SingleQuoteStringIgnore 22
#define DoubleQuoteStringIgnore 23
#define FromMod 24
#define FromModItem 25
#define Import 26
#define TypeHint 27
#define Decorator 28

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#define YY_EXTRA_TYPE struct pyscannerYY_state *

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    yy_state_type *yy_state_buf;
    yy_state_type *yy_state_ptr;
    char *yy_full_match;
    int yy_lp;

    /* These are only needed for trailing context rules,
     * but there's no conditional variable for that yet. */
    int yy_looking_for_trail_begin;
    int yy_full_lp;
    int *yy_full_state;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  , yyscan_t yyscanner);
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! yyg->yy_state_buf )
            yyg->yy_state_buf = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  , yyscanner);
            if ( ! yyg->yy_state_buf )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 275 "/build/doxygen/src/build/generated_src/pyscanner.l"


  /* ------------ Function recognition rules -------------- */

#line 2850 "/build/doxygen/src/build/generated_src/pyscanner_intermediate.cpp"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
		yy_current_state += YY_AT_BOL();

		yyg->yy_state_ptr = yyg->yy_state_buf;
		*yyg->yy_state_ptr++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 766 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			*yyg->yy_state_ptr++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_current_state != 765 );

yy_find_action:
		yy_current_state = *--yyg->yy_state_ptr;
		yyg->yy_lp = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( yyg->yy_lp && yyg->yy_lp < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[yyg->yy_lp];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     yyg->yy_looking_for_trail_begin )
					{
					if ( yy_act == yyg->yy_looking_for_trail_begin )
						{
						yyg->yy_looking_for_trail_begin = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					yyg->yy_looking_for_trail_begin = yy_act & ~YY_TRAILING_MASK;
					yyg->yy_looking_for_trail_begin |= YY_TRAILING_HEAD_MASK;
					yyg->yy_full_match = yy_cp;
					yyg->yy_full_state = yyg->yy_state_ptr;
					yyg->yy_full_lp = yyg->yy_lp;
					}
				else
					{
					yyg->yy_full_match = yy_cp;
					yyg->yy_full_state = yyg->yy_state_ptr;
					yyg->yy_full_lp = yyg->yy_lp;
					break;
					}
				++yyg->yy_lp;
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--yyg->yy_state_ptr;
			yyg->yy_lp = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */

case 1:
YY_RULE_SETUP
#line 281 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a function/method definition with indent
                          DBG_CTX((stderr,"Found def at %d\n",yyextra->yyLineNr));
                          yyextra->indent=computeIndent(yytext);
                          searchFoundDef(yyscanner);
                          BEGIN( FunctionDec );
                        }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 287 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of an async function/method definition with indent
                          DBG_CTX((stderr,"Found async def at %d\n",yyextra->yyLineNr));
                          yyextra->indent=computeIndent(yytext);
                          searchFoundDef(yyscanner);
                          BEGIN( FunctionDec );
                        }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 293 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a function/method definition
                          searchFoundDef(yyscanner);
                          BEGIN( FunctionDec );
                        }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 297 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a function/method definition
                          searchFoundDef(yyscanner);
                          BEGIN( FunctionDec );
                        }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 302 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a class definition with indent
                          DBG_CTX((stderr,"Found class at %d\n",yyextra->yyLineNr));
                          yyextra->indent=computeIndent(yytext);
                          searchFoundClass(yyscanner);
                          BEGIN( ClassDec ) ;
                        }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 308 "/build/doxygen/src/build/generated_src/pyscanner.l"
{  // start of a class definition
                          searchFoundClass(yyscanner);
                          BEGIN( ClassDec ) ;
                       }
	YY_BREAK
case 7:
#line 313 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 8:
YY_RULE_SETUP
#line 313 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of an from import
                          yyextra->packageCommentAllowed = FALSE;
                          BEGIN( FromMod );
                       }
	YY_BREAK
case 9:
#line 319 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 10:
YY_RULE_SETUP
#line 319 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of an import statement
                          yyextra->packageCommentAllowed = FALSE;
                          BEGIN( Import );
                       }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 323 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // property
                        yyextra->current->section   = EntryType::makeVariable();
                        yyextra->current->mtype     = MethodTypes::Property;
                        yyextra->current->name      = QCString(yytext).stripWhiteSpace();
                        yyextra->current->fileName  = yyextra->fileName;
                        yyextra->current->startLine = yyextra->yyLineNr;
                        yyextra->current->bodyLine  = yyextra->yyLineNr;
                        yyextra->packageCommentAllowed = FALSE;
                        BEGIN(VariableDec);
                      }
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 333 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // variable
                        if (yyextra->searchCount>0) REJECT;
                        yyextra->indent=computeIndent(yytext);
                        yyextra->current->section   = EntryType::makeVariable();
                        yyextra->current->name      = QCString(yytext).stripWhiteSpace();
                        yyextra->current->fileName  = yyextra->fileName;
                        yyextra->current->startLine = yyextra->yyLineNr;
                        yyextra->current->bodyLine  = yyextra->yyLineNr;
                        yyextra->packageCommentAllowed = FALSE;
                        BEGIN(VariableDec);
                      }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 344 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // variable
                        if (yyextra->searchCount>0) REJECT;
                        QCString id = QCString(yytext).stripWhiteSpace();
                        if (id =="try" || id == "else" || id == "except" || id == "finally") REJECT;
                        yyextra->indent=computeIndent(yytext);
                        yyextra->current->section   = EntryType::makeVariable();
                        yyextra->current->name      = id;
                        yyextra->current->fileName  = yyextra->fileName;
                        yyextra->current->startLine = yyextra->yyLineNr;
                        yyextra->current->bodyLine  = yyextra->yyLineNr;
                        yyextra->packageCommentAllowed = FALSE;
                        BEGIN(VariableDec);
                      }
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 357 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // list of variables, we cannot place the default value
                                                               // so we will skip it later on in a general rule
                                                               // Also note ")" this is to catch also (a,b). the "("
                                                               // is caught in the rule: [(], the ")" will be handled in [)]
                        if (yyextra->searchCount>1) REJECT;
                        yyextra->indent=computeIndent(yytext);
                        yyextra->current->section   = EntryType::makeVariable();
                        yyextra->current->name      = QCString(yytext).stripWhiteSpace();
                        yyextra->current->fileName  = yyextra->fileName;
                        yyextra->current->startLine = yyextra->yyLineNr;
                        yyextra->current->bodyLine  = yyextra->yyLineNr;
                        yyextra->packageCommentAllowed = FALSE;
                        addVariable(yyscanner);
                      }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 371 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a single quoted string
                        yyextra->stringContext=YY_START;
                        yyextra->copyString=nullptr;
                        yyextra->packageCommentAllowed = FALSE;
                        BEGIN( SingleQuoteString );
                      }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 377 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a double quoted string
                        yyextra->stringContext=YY_START;
                        yyextra->copyString=nullptr;
                        yyextra->packageCommentAllowed = FALSE;
                        BEGIN( DoubleQuoteString );
                      }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 383 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        yyextra->isStatic=TRUE;
                      }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 386 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // decorator
                        lineCount(yyscanner);
                        yyextra->decoratorRound = 1;
                        yyextra->copyString=nullptr;
                        BEGIN( Decorator );
                      }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 392 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // decorator
                        lineCount(yyscanner);
                      }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 395 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // Unix type script comment
                        if (yyextra->yyLineNr != 1) REJECT;
                      }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 398 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // normal comment
                        // issue 9672
                        //yyextra->packageCommentAllowed = FALSE;
                      }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 402 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // some other identifier
                        yyextra->packageCommentAllowed = FALSE;
                      }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 405 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        yyextra->curIndent=computeIndent(yytext);
                      }
	YY_BREAK
case 24:
/* rule 24 can match eol */
YY_RULE_SETUP
#line 409 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // new line
                        lineCount(yyscanner);
                      }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 413 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a comment block
                        initTriDoubleQuoteBlock(yyscanner);
                        BEGIN(TripleComment);
                      }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 418 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a comment block
                        initTriSingleQuoteBlock(yyscanner);
                        BEGIN(TripleComment);
                      }
	YY_BREAK
case 27:
/* rule 27 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 423 "/build/doxygen/src/build/generated_src/pyscanner.l"
{  // start of a special comment
                        yyextra->curIndent=computeIndent(yytext);
                        yyextra->packageCommentAllowed = FALSE;
                        initSpecialBlock(yyscanner);
                        BEGIN(SpecialComment);
                      }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 429 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // we have to do something with (
                        yyextra->searchCount++;
                      }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 432 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // we have to do something with )
                        if (yyextra->searchCount>0)
                        {
                          yyextra->searchCount--;
                        }
                      }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 438 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        yyextra->current->doc.clear();
                        yyextra->current->brief.clear();
                      }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 442 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                      }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 444 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // any other character...
                        // This is the major default
                        // that should catch everything
                        // else in Body.
                      }
	YY_BREAK


case 33:
YY_RULE_SETUP
#line 452 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // python3 style imports
                      }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 454 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // from package import
                        yyextra->packageName=yytext;
                      }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 457 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        BEGIN(FromModItem);
                      }
	YY_BREAK
case 36:
/* rule 36 can match eol */
YY_RULE_SETUP
#line 460 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        incLineNr(yyscanner);
                        BEGIN(Search);
                      }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 464 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                      }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 466 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        unput(*yytext);
                        BEGIN(Search);
                      }
	YY_BREAK


case 39:
YY_RULE_SETUP
#line 473 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // import all
                  addFrom(yyscanner,TRUE);
                  BEGIN(Search);
                }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 477 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                  addFrom(yyscanner,FALSE);
                }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 480 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                  addFrom(yyscanner,FALSE);
                }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 483 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                  addFrom(yyscanner,FALSE);
                  if (!yyextra->importTuple)
                  {
                    BEGIN(Search);
                  }
                }
	YY_BREAK
case 43:
/* rule 43 can match eol */
YY_RULE_SETUP
#line 490 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                  incLineNr(yyscanner);
                  if (!yyextra->importTuple)
                  {
                    BEGIN(Search);
                  }
                }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 497 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 499 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                  yyextra->importTuple=TRUE;
                }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 502 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                  yyextra->importTuple=FALSE;
                  BEGIN(Search);
                }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 506 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                }
	YY_BREAK
case 48:
/* rule 48 can match eol */
YY_RULE_SETUP
#line 508 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // line continuation
                  incLineNr(yyscanner);
                }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 511 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                  unput(*yytext);
                  BEGIN(Search);
                }
	YY_BREAK


case 50:
YY_RULE_SETUP
#line 518 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        yyextra->current->name=removeRedundantWhiteSpace(substitute(yytext,".","::"));
                        yyextra->current->fileName = yyextra->fileName;
                        //printf("Adding using declaration: found:%s:%d name=%s\n",qPrint(yyextra->fileName),yyextra->yyLineNr,qPrint(yyextra->current->name));
                        yyextra->current->section=EntryType::makeUsingDecl();
                        yyextra->current_root->moveToSubEntryAndRefresh(yyextra->current);
                        initEntry(yyscanner);
                        BEGIN(Search);
                      }
	YY_BREAK
case 51:
/* rule 51 can match eol */
YY_RULE_SETUP
#line 527 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                  incLineNr(yyscanner);
                  BEGIN(Search);
                }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 531 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 533 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                  unput(*yytext);
                  BEGIN(Search);
                }
	YY_BREAK


case 54:
YY_RULE_SETUP
#line 540 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        const char *s = strchr(yytext,'.'); s++;
                        DBG_CTX((stderr,"Found instance method variable %s in %s at %d\n",s,qPrint(yyextra->current_root->name.data(),yyextra->yyLineNr)));
                        docVariable(yyscanner,s);
                        addEntry(yyscanner);
                      }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 546 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        const char *s = strchr(yytext,'.'); s++;
                        DBG_CTX((stderr,"Found instance method variable %s in %s at %d\n",s,qPrint(yyextra->current_root->name.data(),yyextra->yyLineNr)));
                        docVariable(yyscanner,s);
                        BEGIN( SearchSkipValue  );
                      }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 552 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // type hint
                        const char *s = strchr(yytext,'.'); s++;
                        DBG_CTX((stderr,"Found instance method variable %s in %s at %d\n",s,qPrint(yyextra->current_root->name.data(),yyextra->yyLineNr)));
                        docVariable(yyscanner,s);
                        BEGIN(TypeHint);
                      }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 558 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a comment block
                        initTriDoubleQuoteBlock(yyscanner);
                        BEGIN(TripleComment);
                      }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 563 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a comment block
                        initTriSingleQuoteBlock(yyscanner);
                        BEGIN(TripleComment);
                      }
	YY_BREAK
case 59:
/* rule 59 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 2);
yyg->yy_c_buf_p = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 568 "/build/doxygen/src/build/generated_src/pyscanner.l"
{  // start of a special comment
                        initSpecialBlock(yyscanner);
                        BEGIN(SpecialComment);
                      }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 572 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // #
                      }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 574 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a single quoted string
                        yyextra->stringContext=YY_START;
                        yyextra->copyString=nullptr;
                        BEGIN( SingleQuoteString );
                      }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 579 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a double quoted string
                        yyextra->stringContext=YY_START;
                        yyextra->copyString=nullptr;
                        BEGIN( DoubleQuoteString );
                      }
	YY_BREAK
case 63:
/* rule 63 can match eol */
YY_RULE_SETUP
#line 584 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ incLineNr(yyscanner); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 585 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        yyextra->current->doc.clear();
                        yyextra->current->brief.clear();
                        unput(*yytext);
                        BEGIN( SearchSkipValue  );
                      }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 591 "/build/doxygen/src/build/generated_src/pyscanner.l"
// identifiers
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 592 "/build/doxygen/src/build/generated_src/pyscanner.l"
// other uninteresting stuff
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 593 "/build/doxygen/src/build/generated_src/pyscanner.l"
// anything else
	YY_BREAK


case 68:
YY_RULE_SETUP
#line 597 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // skip over start of type hint
                          yyextra->braceCount=0;
                        }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 600 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->current->type+=*yytext;
                          yyextra->braceCount++;
                        }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 604 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->current->type+=*yytext;
                          yyextra->braceCount--;
                        }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 608 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a single quoted string
                          yyextra->stringContext=YY_START;
                          yyextra->copyString=nullptr;
                          BEGIN( SingleQuoteString );
                        }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 613 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a double quoted string
                          yyextra->stringContext=YY_START;
                          yyextra->copyString=nullptr;
                          BEGIN( DoubleQuoteString );
                        }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 618 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          if (yyextra->braceCount==0)
                          { // end of the type hint
                            yyextra->current->type = yyextra->current->type.stripWhiteSpace();
                            unput(*yytext);
                            BEGIN(SearchSkipValue);
                          }
                          else
                          {
                            yyextra->current->type+=*yytext;
                          }
                        }
	YY_BREAK
case 74:
/* rule 74 can match eol */
YY_RULE_SETUP
#line 630 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // end of the type hint
                          yyextra->current->type = yyextra->current->type.stripWhiteSpace();
                          incLineNr(yyscanner);
                          newEntry(yyscanner);
                          BEGIN(SearchMemVars);
                        }
	YY_BREAK
case 75:
/* rule 75 can match eol */
YY_RULE_SETUP
#line 636 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->current->type+=' ';
                          incLineNr(yyscanner);
                        }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 640 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->current->type+=*yytext;
                        }
	YY_BREAK


case 77:
YY_RULE_SETUP
#line 646 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // the assignment operator
                        //printf("====== VariableDec at line %d\n",yyextra->yyLineNr);
                        yyextra->startInit = TRUE;
                        yyextra->current->initializer.str(yytext);
                        yyextra->current->initializer << " ";
                      }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 652 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // spaces
                        yyextra->current->initializer << yytext;
                      }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 656 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // integer value
                        if (yyextra->current->type.isEmpty()) yyextra->current->type = "int";
                        yyextra->current->initializer << yytext;
                      }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 660 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // floating point value
                        if (yyextra->current->type.isEmpty()) yyextra->current->type = "float";
                        yyextra->current->initializer << yytext;
                      }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 664 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // boolean value
                        if (yyextra->current->type.isEmpty()) yyextra->current->type = "bool";
                        yyextra->current->initializer << yytext;
                      }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 668 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // string
                        if (yyextra->current->type.isEmpty()) yyextra->current->type = "str";
                        yyextra->current->initializer << yytext;
                        yyextra->copyString=&yyextra->current->initializer;
                        yyextra->stringContext=YY_START;
                        BEGIN( SingleQuoteString );
                      }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 675 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // string
                        if (yyextra->current->type.isEmpty()) yyextra->current->type = "str";
                        yyextra->current->initializer << yytext;
                        yyextra->copyString=&yyextra->current->initializer;
                        yyextra->stringContext=YY_START;
                        BEGIN( DoubleQuoteString );
                      }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 682 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a comment block
                        if (yyextra->current->type.isEmpty()) yyextra->current->type = "str";
                        yyextra->current->initializer << yytext;
                        yyextra->doubleQuote=TRUE;
                        yyextra->copyString=&yyextra->current->initializer;
                        yyextra->stringContext=YY_START;
                        BEGIN(TripleString);
                      }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 691 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a comment block
                        if (yyextra->current->type.isEmpty()) yyextra->current->type = "str";
                        yyextra->current->initializer << yytext;
                        yyextra->doubleQuote=FALSE;
                        yyextra->copyString=&yyextra->current->initializer;
                        yyextra->stringContext=YY_START;
                        BEGIN(TripleString);
                      }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 699 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // tuple, only when direct after =
                        if (yyextra->current->mtype!=MethodTypes::Property && yyextra->startInit)
                        {
                          yyextra->current->type = "tuple";
                        }
                        yyextra->current->initializer << *yytext;
                        yyextra->atomStart='(';
                        yyextra->atomEnd=')';
                        yyextra->atomCount=1;
                        yyextra->atomContext=YY_START;
                        BEGIN( VariableAtom );
                      }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 711 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // list
                        if (yyextra->startInit) yyextra->current->type = "list";
                        yyextra->current->initializer << *yytext;
                        yyextra->atomStart='[';
                        yyextra->atomEnd=']';
                        yyextra->atomCount=1;
                        yyextra->atomContext=YY_START;
                        BEGIN( VariableAtom );
                      }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 720 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // dictionary
                        if (yyextra->startInit) yyextra->current->type = "dict";
                        yyextra->current->initializer << *yytext;
                        yyextra->atomStart='{';
                        yyextra->atomEnd='}';
                        yyextra->atomCount=1;
                        yyextra->atomContext=YY_START;
                        BEGIN( VariableAtom );
                      }
	YY_BREAK
case 89:
/* rule 89 can match eol */
YY_RULE_SETUP
#line 729 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        yyextra->current->initializer << yytext;
                        incLineNr(yyscanner);
                      }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 733 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        // do something based on the type of the IDENTIFIER
                        if (yyextra->current->type.isEmpty())
                        {
                          for (const auto &child : yyextra->current_root->children())
                          {
                            if (child->name == yytext)
                            {
                               yyextra->current->type = child->type;
                               break;
                            }
                          }
                        }
                        yyextra->startInit = FALSE;
                        yyextra->current->initializer << yytext;
                      }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 749 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        yyextra->startInit = FALSE;
                        yyextra->current->initializer << *yytext;
                      }
	YY_BREAK


case 92:
/* rule 92 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 2);
yyg->yy_c_buf_p = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 755 "/build/doxygen/src/build/generated_src/pyscanner.l"
{  // start of a special comment
                        initSpecialBlock(yyscanner);
                        BEGIN(SpecialComment);
                      }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 759 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // #
                      }
	YY_BREAK
case 94:
/* rule 94 can match eol */
YY_RULE_SETUP
#line 761 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ incLineNr(yyscanner);
                        newEntry(yyscanner);
                        BEGIN(SearchMemVars);
                      }
	YY_BREAK
case YY_STATE_EOF(SearchSkipValue):
#line 765 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ incLineNr(yyscanner);
                        newEntry(yyscanner);
                        BEGIN(SearchMemVars);
                      }
	YY_BREAK


case 95:
/* rule 95 can match eol */
YY_RULE_SETUP
#line 772 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        DBG_CTX((stderr,"indent %d<=%d\n",computeIndent(&yytext[1]),yyextra->indent));
                        if (computeIndent(&yytext[1])<=yyextra->indent)
                        {
                          unput_string(yytext,yyleng);
                          endOfDef(yyscanner);
                          //YY_CURRENT_BUFFER->yy_at_bol=TRUE;
                          BEGIN(Search);
                        }
                        else
                        {
                          incLineNr(yyscanner);
                          yyextra->current->program << yytext;
                        }
                      }
	YY_BREAK
case 96:
/* rule 96 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 2);
yyg->yy_c_buf_p = yy_cp -= 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 787 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        if (computeIndent(&yytext[1])<=yyextra->indent)
                        {
                          unput_string(yytext,yyleng);
                          endOfDef(yyscanner);
                          //YY_CURRENT_BUFFER->yy_at_bol=TRUE;
                          BEGIN(Search);
                        }
                        else
                        {
                          incLineNr(yyscanner);
                          yyextra->current->program << yytext;
                        }
                      }
	YY_BREAK
case YY_STATE_EOF(FunctionBody):
#line 801 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        endOfDef(yyscanner);
                        yyterminate();
                      }
	YY_BREAK
case 97:
/* rule 97 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 805 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // skip empty line
                        yyextra->current->program << yytext;
                      }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 808 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // something at indent >0
                        yyextra->curIndent = computeIndent(yytext);
                        if (yyextra->curIndent<=yyextra->indent)
                          // jumped out of the function
                        {
                          endOfDef(yyscanner,1);
                          BEGIN(Search);
                        }
                        else
                        {
                          yyextra->current->program << yytext;
                        }
                      }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 821 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a single quoted string
                        yyextra->current->program << yytext;
                        yyextra->stringContext=YY_START;
                        yyextra->specialBlock = FALSE;
                        yyextra->copyString=&yyextra->current->program;
                        BEGIN( SingleQuoteString );
                      }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 828 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a double quoted string
                        yyextra->current->program << yytext;
                        yyextra->stringContext=YY_START;
                        yyextra->specialBlock = FALSE;
                        yyextra->copyString=&yyextra->current->program;
                        BEGIN( DoubleQuoteString );
                      }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 835 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // non-special stuff
                        yyextra->current->program << yytext;
                        yyextra->specialBlock = FALSE;
                      }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 839 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // normal comment
                        yyextra->current->program << yytext;
                      }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 842 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // comment half way
                        yyextra->current->program << yytext;
                      }
	YY_BREAK
case 104:
/* rule 104 can match eol */
YY_RULE_SETUP
#line 845 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        incLineNr(yyscanner);
                        yyextra->current->program << yytext;
                      }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 849 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // any character
                        yyextra->current->program << *yytext;
                        yyextra->specialBlock = FALSE;
                      }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 854 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a comment block
                        yyextra->current->program << yytext;
                        initTriDoubleQuoteBlock(yyscanner);
                        BEGIN(TripleComment);
                      }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 860 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a comment block
                        yyextra->current->program << yytext;
                        initTriSingleQuoteBlock(yyscanner);
                        BEGIN(TripleComment);
                      }
	YY_BREAK


case 108:
YY_RULE_SETUP
#line 869 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                              //found function name
                              yyextra->current->name = yytext;
                              yyextra->current->name = yyextra->current->name.stripWhiteSpace();
                              newFunction(yyscanner);
                            }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 875 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // function without arguments
                              yyextra->specialBlock = TRUE; // expecting a docstring
                              yyextra->bodyEntry = yyextra->current;
                              yyextra->current->bodyLine  = yyextra->yyLineNr;
                              BEGIN(FunctionBody);
                            }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 882 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                              yyextra->defVal.str(std::string());
                              yyextra->braceCount = 0;
                              BEGIN(FunctionTypeAnnotation);
                            }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 887 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                              yyextra->funcParamsEnd = FALSE;
                              yyextra->current->bodyLine  = yyextra->yyLineNr;
                              BEGIN(FunctionParams);
                            }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 892 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // end of parameter list
                              if (yyextra->current->argList.empty())
                              {
                                yyextra->current->argList.setNoParameters(TRUE);
                              }
                              yyextra->current->args = argListToString(yyextra->current->argList);
                              yyextra->funcParamsEnd = TRUE;
                            }
	YY_BREAK


case 113:
YY_RULE_SETUP
#line 903 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 906 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          if (!yyextra->argType.isEmpty())
                          {
                            Argument a;
                            a.name = "";
                            a.type = yyextra->argType;
                            yyextra->current->argList.push_back(a);
                            yyextra->argType = "";
                          }
                        }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 917 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->argType = yytext;
                        }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 920 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // Name of parameter
                          lineCount(yyscanner);
                          Argument a;
                          a.name = QCString(yytext).stripWhiteSpace();
                          a.type = yyextra->argType;
                          yyextra->current->argList.push_back(a);
                          yyextra->argType = "";
                        }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 928 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // default value
                          // TODO: this rule is too simple, need to be able to
                          // match things like =")" as well!
                          yyextra->defVal.str(std::string());
                          yyextra->braceCount = 0;
                          BEGIN(FunctionParamDefVal);
                        }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 935 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          if (!yyextra->argType.isEmpty())
                          {
                            Argument a;
                            a.name = "";
                            a.type = yyextra->argType;
                            yyextra->current->argList.push_back(a);
                            yyextra->argType = "";
                          }
                          unput(*yytext);
                          BEGIN(FunctionDec);
                        }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 947 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->defVal.str(std::string());
                          yyextra->braceCount = 0;
                          BEGIN(FunctionAnnotation);
                        }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 952 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // a comment
                        }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 954 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // Default rule inside arguments.
                        }
	YY_BREAK


case 122:
#line 961 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 123:
#line 962 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 124:
YY_RULE_SETUP
#line 962 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          ++yyextra->braceCount;
                          yyextra->defVal << *yytext;
                        }
	YY_BREAK
case 125:
#line 967 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 126:
#line 968 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 127:
YY_RULE_SETUP
#line 968 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          --yyextra->braceCount;
                          yyextra->defVal << *yytext;
                        }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 972 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          if (yyextra->braceCount == 0)
                          {
                            yyextra->current->type = yyextra->defVal.str();
                            unput(*yytext);
                            BEGIN(FunctionDec);
                          }
                          else
                            yyextra->defVal << *yytext;
                        }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 982 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->defVal << *yytext;
                          yyextra->copyString=&yyextra->defVal;
                          yyextra->stringContext=FunctionTypeAnnotation;
                          BEGIN(SingleQuoteString);
                        }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 988 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->defVal << *yytext;
                          yyextra->copyString=&yyextra->defVal;
                          yyextra->stringContext=FunctionTypeAnnotation;
                          BEGIN(DoubleQuoteString);
                        }
	YY_BREAK
case 131:
/* rule 131 can match eol */
YY_RULE_SETUP
#line 994 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->defVal << *yytext;
                          incLineNr(yyscanner);
                        }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 998 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->defVal << *yytext;
                        }
	YY_BREAK


case 133:
#line 1005 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 134:
#line 1006 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 135:
YY_RULE_SETUP
#line 1006 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          ++yyextra->braceCount;
                          yyextra->defVal << *yytext;
                        }
	YY_BREAK
case 136:
#line 1011 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 137:
YY_RULE_SETUP
#line 1011 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          --yyextra->braceCount;
                          yyextra->defVal << *yytext;
                        }
	YY_BREAK
case 138:
#line 1016 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 139:
#line 1017 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 140:
YY_RULE_SETUP
#line 1017 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          if (yyextra->braceCount == 0)
                          {
                            if (!yyextra->current->argList.empty())
                              yyextra->current->argList.back().type += yyextra->defVal.str();
                            if (*yytext != ',')
                              unput(*yytext);
                            BEGIN(FunctionParams);
                          }
                          else
                          {
                            if (*yytext == ')')
                              --yyextra->braceCount;
                            yyextra->defVal << *yytext;
                          }
                        }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 1033 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->defVal << *yytext;
                          yyextra->copyString=&yyextra->defVal;
                          yyextra->stringContext=FunctionAnnotation;
                          BEGIN(SingleQuoteString);
                        }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 1039 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->defVal << *yytext;
                          yyextra->copyString=&yyextra->defVal;
                          yyextra->stringContext=FunctionAnnotation;
                          BEGIN(DoubleQuoteString);
                        }
	YY_BREAK
case 143:
/* rule 143 can match eol */
YY_RULE_SETUP
#line 1045 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->defVal << *yytext;
                          incLineNr(yyscanner);
                        }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 1049 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->defVal << *yytext;
                        }
	YY_BREAK


case 145:
#line 1056 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 146:
#line 1057 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 147:
YY_RULE_SETUP
#line 1057 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // internal opening brace, assumption is that we have correct code so braces do match
                          ++yyextra->braceCount;
                          yyextra->defVal << *yytext;
                        }
	YY_BREAK
case 148:
#line 1062 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 149:
YY_RULE_SETUP
#line 1062 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          --yyextra->braceCount;
                          yyextra->defVal << *yytext;
                        }
	YY_BREAK
case 150:
#line 1067 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 151:
YY_RULE_SETUP
#line 1067 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          if (yyextra->braceCount == 0)
                          {
                            if (!yyextra->current->argList.empty())
                              yyextra->current->argList.back().defval=QCString(yyextra->defVal.str()).stripWhiteSpace();
                            if (*yytext == ')')
                              unput(*yytext);
                            BEGIN(FunctionParams);
                          }
                          else
                          {
                            if (*yytext == ')')
                              --yyextra->braceCount;
                            yyextra->defVal << *yytext;
                          }
                        }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 1084 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->defVal << *yytext;
                          yyextra->copyString=&yyextra->defVal;
                          yyextra->stringContext=FunctionParamDefVal;
                          BEGIN( SingleQuoteString );
                        }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 1090 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->defVal << *yytext;
                          yyextra->copyString=&yyextra->defVal;
                          yyextra->stringContext=FunctionParamDefVal;
                          BEGIN( DoubleQuoteString );
                        }
	YY_BREAK
case 154:
/* rule 154 can match eol */
YY_RULE_SETUP
#line 1096 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                            yyextra->defVal << *yytext;
                            incLineNr(yyscanner);
                        }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 1100 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                            yyextra->defVal << *yytext;
                        }
	YY_BREAK


case 156:
/* rule 156 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 1);
yyg->yy_c_buf_p = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 1107 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // new def at indent 0
                        if (computeIndent(&yytext[1])<=yyextra->indent)
                        {
                          int i;
                          for (i=(int)yyleng-1;i>=0;i--)
                          {
                            unput(yytext[i]);
                          }
                          endOfDef(yyscanner);
                          //YY_CURRENT_BUFFER->yy_at_bol=TRUE;
                          BEGIN(Search);
                        }
                        else
                        {
                          incLineNr(yyscanner);
                          yyextra->current->program << yytext;
                        }
                      }
	YY_BREAK
case 157:
/* rule 157 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 1);
yyg->yy_c_buf_p = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 1125 "/build/doxygen/src/build/generated_src/pyscanner.l"
{  // start of a special comment at indent 0
                        if (computeIndent(&yytext[1])<=yyextra->indent)
                        {
                          int i;
                          for (i=(int)yyleng-1;i>=0;i--)
                          {
                            unput(yytext[i]);
                          }
                          endOfDef(yyscanner);
                          //YY_CURRENT_BUFFER->yy_at_bol=TRUE;
                          BEGIN(Search);
                        }
                        else
                        {
                          incLineNr(yyscanner);
                          yyextra->current->program << yytext;
                        }
                      }
	YY_BREAK
case 158:
/* rule 158 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 1143 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // skip empty line
                        yyextra->current->program << yytext;
                      }
	YY_BREAK
case YY_STATE_EOF(ClassBody):
#line 1146 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        endOfDef(yyscanner);
                        yyterminate();
                      }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 1150 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // something at indent >0
                        yyextra->curIndent=computeIndent(yytext);
                        DBG_CTX((stderr,"yyextra->curIndent=%d yyextra->indent=%d\n",yyextra->curIndent,yyextra->indent));
                        if (yyextra->curIndent<=yyextra->indent)
                          // jumped out of the class/method
                        {
                          endOfDef(yyscanner,1);
                          yyextra->indent=yyextra->curIndent;
                          // make sure the next rule matches ^...
                          //YY_CURRENT_BUFFER->yy_at_bol=TRUE;
                          //yyextra->hideClassDocs = FALSE;
                          BEGIN(Search);
                        }
                        else
                        {
                          yyextra->current->program << yytext;
                        }
                      }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 1168 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a single quoted string
                        yyextra->current->program << *yytext;
                        yyextra->stringContext=YY_START;
                        yyextra->specialBlock = FALSE;
                        yyextra->copyString=&yyextra->current->program;
                        BEGIN( SingleQuoteString );
                      }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 1175 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a double quoted string
                        yyextra->current->program << *yytext;
                        yyextra->stringContext=YY_START;
                        yyextra->specialBlock = FALSE;
                        yyextra->copyString=&yyextra->current->program;
                        BEGIN( DoubleQuoteString );
                      }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 1182 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // non-special stuff
                        yyextra->current->program << yytext;
                        yyextra->specialBlock = FALSE;
                        //yyextra->hideClassDocs = FALSE;
                      }
	YY_BREAK
case 163:
/* rule 163 can match eol */
YY_RULE_SETUP
#line 1187 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        yyextra->current->program << *yytext;
                        incLineNr(yyscanner);
                      }
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 1191 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // normal comment
                        yyextra->current->program << yytext;
                      }
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 1194 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // any character
                        yyextra->specialBlock = FALSE;
                        yyextra->current->program << *yytext;
                      }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 1198 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a comment block
                        //if (!yyextra->hideClassDocs)
                        yyextra->current->program << yytext;
                        initTriDoubleQuoteBlock(yyscanner);
                        BEGIN(TripleComment);
                      }
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 1205 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a comment block
                        //if (!yyextra->hideClassDocs)
                        yyextra->current->program << yytext;
                        initTriSingleQuoteBlock(yyscanner);
                        BEGIN(TripleComment);
                      }
	YY_BREAK

case 168:
YY_RULE_SETUP
#line 1213 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          if (yyextra->current->type.isEmpty())
                          {
                              yyextra->current->type = "class";
                          }

                          yyextra->current->section = EntryType::makeClass();
                          yyextra->current->name = yytext;
                          // we need to set the protectiion based on the "local" class name
                          setProtection(yyscanner);

                          // prepend scope in case of nested classes
                          if (yyextra->current_root->section.isScope())
                          {
                            //printf("*** Prepending scope %s to class %s\n",qPrint(yyextra->current_root->name),qPrint(yyextra->current->name));
                            yyextra->current->name.prepend(yyextra->current_root->name+"::");
                          }

                          yyextra->current->name = yyextra->current->name.stripWhiteSpace();
                          yyextra->current->fileName = yyextra->fileName;
                          yyextra->docBlockContext   = YY_START;
                          yyextra->docBlockInBody    = FALSE;
                          yyextra->docBlockJavaStyle = FALSE;
                          yyextra->docBlock.clear();
                          yyextra->bracketDepth = 0;

                          BEGIN(ClassInheritance);
                        }
	YY_BREAK

case 169:
YY_RULE_SETUP
#line 1243 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // syntactic sugar for the list
                       }
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 1245 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                         yyextra->bracketDepth++;
                       }
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 1248 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                         if (yyextra->bracketDepth > 0)
                           yyextra->bracketDepth--;
                       }
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 1252 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // begin of the class definition
                         yyextra->specialBlock = TRUE; // expecting a docstring
                         yyextra->current->bodyLine  = yyextra->yyLineNr;
                         yyextra->current->program.str(std::string());
                         BEGIN(ClassCaptureIndent);
                       }
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 1259 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                         if (yyextra->bracketDepth == 0)
                         {
                           yyextra->current->extends.emplace_back(
                                                substitute(yytext,".","::"),Protection::Public,Specifier::Normal
                                            );
                         }
                         //Has base class-do stuff
                       }
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 1268 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a single quoted string
                         yyextra->stringContext=YY_START;
                         BEGIN( SingleQuoteStringIgnore );
                       }
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 1272 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a double quoted string
                         yyextra->stringContext=YY_START;
                         BEGIN( DoubleQuoteStringIgnore );
                       }
	YY_BREAK


case 176:
YY_RULE_SETUP
#line 1279 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // end of a single quoted string
                         BEGIN(yyextra->stringContext);
                       }
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 1282 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ }
	YY_BREAK


case 178:
YY_RULE_SETUP
#line 1285 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // end of a double quoted string
                         BEGIN(yyextra->stringContext);
                       }
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 1288 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ }
	YY_BREAK


case 180:
/* rule 180 can match eol */
YY_RULE_SETUP
#line 1292 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                                 // Blankline - ignore, keep looking for indentation.
                                 lineCount(yyscanner);
                                 yyextra->current->program << yytext;
                               }
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 1298 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a comment block
                                 initTriDoubleQuoteBlock(yyscanner);
                                 yyextra->current->program << yytext;
                                 BEGIN(TripleComment);
                               }
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 1303 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a comment block
                                 initTriSingleQuoteBlock(yyscanner);
                                 yyextra->current->program << yytext;
                                 BEGIN(TripleComment);
                               }
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 1308 "/build/doxygen/src/build/generated_src/pyscanner.l"
{  // start of a special comment
                                 initSpecialBlock(yyscanner);
                                 BEGIN(SpecialComment);
                               }
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 1312 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // ignore comment with just one #
                               }
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 1314 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                                 yyextra->current->program << yytext;
                                 //yyextra->current->startLine = yyextra->yyLineNr;
                                 yyextra->curIndent=computeIndent(yytext);
                                 yyextra->bodyEntry = yyextra->current;
                                 DBG_CTX((stderr,"setting indent %d\n",yyextra->curIndent));
                                 //printf("yyextra->current->program=[%s]\n",qPrint(yyextra->current->program));
                                 //yyextra->hideClassDocs = TRUE;
                                 BEGIN(ClassBody);
                               }
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 1325 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                                 // Just pushback an empty class, and
                                 // resume parsing the body.
                                 newEntry(yyscanner);
                                 yyextra->current->program << yytext;

                                 // printf("Failed to find indent - skipping!");
                                 BEGIN( Search );
                               }
	YY_BREAK


case 187:
YY_RULE_SETUP
#line 1338 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ //typing
                        yyextra->startInit = FALSE;
                        yyextra->current->type = substitute(yytext,":","");
                      }
	YY_BREAK
case 188:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 1342 "/build/doxygen/src/build/generated_src/pyscanner.l"
{  // start of a special comment
                        yyextra->curIndent=computeIndent(yytext);
                        yyextra->packageCommentAllowed = FALSE;
                        initSpecialBlock(yyscanner);
                        yyextra->docBlockContext = VariableEnd;
                        BEGIN(SpecialComment);
                      }
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 1349 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // comment
                        BEGIN( VariableEnd );
                      }
	YY_BREAK
case 190:
/* rule 190 can match eol */
YY_RULE_SETUP
#line 1352 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        unput('\n');
                        BEGIN( VariableEnd );
                      }
	YY_BREAK


case 191:
YY_RULE_SETUP
#line 1359 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        yyextra->current->initializer << *yytext;
                        if (yyextra->atomStart==*yytext)
                        {
                          yyextra->atomCount++;
                        }
                      }
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 1366 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        yyextra->current->initializer << *yytext;
                        if (yyextra->atomEnd==*yytext)
                        {
                          yyextra->atomCount--;
                        }
                        if (yyextra->atomCount==0)
                        {
                          yyextra->startInit = FALSE;
                          BEGIN(yyextra->atomContext);
                        }
                      }
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 1378 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a comment block
                        yyextra->specialBlock = FALSE;
                        yyextra->current->program << yytext;
                        initTriDoubleQuoteBlock(yyscanner);
                        BEGIN(TripleComment);
                      }
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 1385 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a comment block
                        yyextra->specialBlock = FALSE;
                        yyextra->current->program << yytext;
                        initTriSingleQuoteBlock(yyscanner);
                        BEGIN(TripleComment);
                      }
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 1391 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        yyextra->stringContext=YY_START;
                        yyextra->current->initializer << "'";
                        yyextra->copyString=&yyextra->current->initializer;
                        BEGIN( SingleQuoteString );
                      }
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 1397 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        yyextra->stringContext=YY_START;
                        yyextra->current->initializer << "\"";
                        yyextra->copyString=&yyextra->current->initializer;
                        BEGIN( DoubleQuoteString );
                      }
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 1403 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        yyextra->current->initializer << yytext;
                      }
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 1406 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        yyextra->current->initializer << *yytext;
                      }
	YY_BREAK
case 199:
/* rule 199 can match eol */
YY_RULE_SETUP
#line 1409 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        yyextra->current->initializer << *yytext;
                        incLineNr(yyscanner);
                      }
	YY_BREAK


case 200:
/* rule 200 can match eol */
YY_RULE_SETUP
#line 1417 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        incLineNr(yyscanner);
                        if (!stripWhiteSpace(yyextra->current->initializer.str()).empty())
                        {
                          newVariable(yyscanner);
                        }
                        BEGIN(Search);
                      }
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 1425 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                        unput(*yytext);
                        newVariable(yyscanner);
                        BEGIN(Search);
                      }
	YY_BREAK
case YY_STATE_EOF(VariableEnd):
#line 1430 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ yyterminate();
                      }
	YY_BREAK


case 202:
#line 1436 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 203:
YY_RULE_SETUP
#line 1436 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          // printf("Expected module block %d special=%d\n",yyextra->expectModuleDocs,yyextra->specialBlock);
                          if (yyextra->doubleQuote==(yytext[0]=='"'))
                          {
                            if (yyextra->specialBlock) // expecting a docstring
                            {
                              QCString actualDoc=yyextra->docBlock;
                              if (!yyextra->docBlockSpecial) // legacy unformatted docstring
                              {
                                if (!actualDoc.isEmpty())
                                {
                                  stripIndentationVerbatim(actualDoc,yyextra->commentIndent);
                                  actualDoc.prepend("@iverbatim\n");
                                  actualDoc.append("@endiverbatim ");
                                }
                              }
                              //printf("-------> yyextra->current=%p yyextra->bodyEntry=%p\n",yyextra->current,yyextra->bodyEntry);
                              handleCommentBlock(yyscanner, actualDoc, FALSE);
                            }
                            else if (yyextra->packageCommentAllowed) // expecting module docs
                            {
                              QCString actualDoc=yyextra->docBlock;
                              if (!yyextra->docBlockSpecial) // legacy unformatted docstring
                              {
                                if (!actualDoc.isEmpty())
                                {
                                  stripIndentationVerbatim(actualDoc,yyextra->commentIndent);
                                  actualDoc.prepend("@iverbatim\n");
                                  actualDoc.append("@endiverbatim ");
                                }
                              }
                              if (yyextra->moduleScope.startsWith("__") &&  yyextra->moduleScope.endsWith("__"))
                              {
                                actualDoc.prepend("\\namespace \\"+yyextra->moduleScope+" ");
                              }
                              else
                              {
                                actualDoc.prepend("\\namespace "+yyextra->moduleScope+" ");
                              }
                              handleCommentBlock(yyscanner, actualDoc, FALSE);
                            }
                            if ((yyextra->docBlockContext==ClassBody /*&& !yyextra->hideClassDocs*/) ||
                                yyextra->docBlockContext==FunctionBody)
                            {
                              yyextra->current->program << yyextra->docBlock;
                              yyextra->current->program << yytext;
                            }
                            //if (yyextra->hideClassDocs)
                            //{
                            //  yyextra->current->startLine = yyextra->yyLineNr;
                            //}
                            //yyextra->hideClassDocs=FALSE;
                            BEGIN(yyextra->docBlockContext);
                          }
                          else
                          {
                            yyextra->docBlock += yytext;
                          }
                          yyextra->packageCommentAllowed = FALSE;
                        }
	YY_BREAK
case 204:
YY_RULE_SETUP
#line 1498 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // leading whitespace, compensate for """! / '''!
                          if (yyextra->firstPass && yyextra->docBlockSpecial && yyleng >= yyextra->curIndent)
                            yyextra->docBlock += yytext + yyextra->curIndent;
                          else
                            yyextra->docBlock += yytext;
                        }
	YY_BREAK
case 205:
YY_RULE_SETUP
#line 1504 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->docBlock += yytext;
                        }
	YY_BREAK
case 206:
/* rule 206 can match eol */
YY_RULE_SETUP
#line 1507 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          incLineNr(yyscanner);
                          yyextra->docBlock += yytext;
                        }
	YY_BREAK
case 207:
YY_RULE_SETUP
#line 1511 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                                    yyextra->fileName = &yytext[6];
                                    yyextra->fileName = yyextra->fileName.stripWhiteSpace();
                                    yyextra->fileName = yyextra->fileName.mid(1,yyextra->fileName.length()-2);
                                    yyextra->docBlock+=yytext;
                                  }
	YY_BREAK
case 208:
YY_RULE_SETUP
#line 1517 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                                    yyextra->fileName = &yytext[6];
                                    yyextra->fileName = yyextra->fileName.stripWhiteSpace();
                                    yyextra->docBlock+=yytext;
                                  }
	YY_BREAK
case 209:
/* rule 209 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
#line 1523 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 210:
/* rule 210 can match eol */
YY_RULE_SETUP
#line 1523 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                                    bool ok = false;
                                    int nr = QCString(&yytext[6]).toInt(&ok);
                                    if (!ok)
                                    {
                                      warn(yyextra->fileName,yyextra->yyLineNr,"Invalid line number '{}' for iline command",yytext);
                                    }
                                    else
                                    {
                                      yyextra->yyLineNr = nr;
                                    }
                                    yyextra->docBlock+=yytext;
                                  }
	YY_BREAK
case 211:
/* rule 211 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 1536 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // escaped command
                                     yyextra->docBlock+=yytext;
                                  }
	YY_BREAK
case 212:
YY_RULE_SETUP
#line 1539 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // escaped char TO be extended
                          yyextra->docBlock += yytext;
                        }
	YY_BREAK
case 213:
YY_RULE_SETUP
#line 1542 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->docBlock += yytext;
                        }
	YY_BREAK


case 214:
YY_RULE_SETUP
#line 1548 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // skip leading hashes
                        }
	YY_BREAK
case 215:
/* rule 215 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 1);
yyg->yy_c_buf_p = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 1550 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // continuation of the comment on the next line
                          yyextra->docBlock+='\n';
                          yyextra->docBrief = FALSE;
                          incLineNr(yyscanner);
                        }
	YY_BREAK
case 216:
YY_RULE_SETUP
#line 1555 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                                    yyextra->fileName = &yytext[6];
                                    yyextra->fileName = yyextra->fileName.stripWhiteSpace();
                                    yyextra->fileName = yyextra->fileName.mid(1,yyextra->fileName.length()-2);
                                    yyextra->docBlock+=yytext;
                                  }
	YY_BREAK
case 217:
YY_RULE_SETUP
#line 1561 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                                    yyextra->fileName = &yytext[6];
                                    yyextra->fileName = yyextra->fileName.stripWhiteSpace();
                                    yyextra->docBlock+=yytext;
                                  }
	YY_BREAK
case 218:
/* rule 218 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
#line 1567 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 219:
/* rule 219 can match eol */
YY_RULE_SETUP
#line 1567 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                                    bool ok = false;
                                    int nr = QCString(&yytext[6]).toInt(&ok);
                                    if (!ok)
                                    {
                                      warn(yyextra->fileName,yyextra->yyLineNr,"Invalid line number '{}' for iline command",yytext);
                                    }
                                    else
                                    {
                                      yyextra->yyLineNr = nr;
                                    }
                                    yyextra->docBlock+=yytext;
                                  }
	YY_BREAK
case 220:
/* rule 220 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 1580 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // escaped command
                                     yyextra->docBlock+=yytext;
                                  }
	YY_BREAK
case 221:
YY_RULE_SETUP
#line 1583 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          QCString indent;
                          int extraSpaces = std::max(0,static_cast<int>(yyleng-9-yyextra->curIndent-2));
                          indent.fill(' ',extraSpaces);
                          //printf("extraSpaces=%d\n",extraSpaces);
                          yyextra->docBlock += "\\ilinebr ";
                          yyextra->docBlock += indent;
                        }
	YY_BREAK
case 222:
YY_RULE_SETUP
#line 1591 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // any other stuff
                          yyextra->docBlock+=yytext;
                        }
	YY_BREAK
case 223:
/* rule 223 can match eol */
YY_RULE_SETUP
#line 1594 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // new line that ends the comment
                          handleCommentBlock(yyscanner, yyextra->docBlock, yyextra->docBrief);
                          if (yyextra->docBlockContext == VariableEnd)
                          {
                            unput(*yytext);
                          }
                          else
                          {
                            incLineNr(yyscanner);
                          }
                          BEGIN(yyextra->docBlockContext);
                        }
	YY_BREAK
case 224:
YY_RULE_SETUP
#line 1606 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // anything we missed
                          yyextra->docBlock+=*yytext;
                        }
	YY_BREAK


case 225:
/* rule 225 can match eol */
YY_RULE_SETUP
#line 1612 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // line continuation
                                 addToString(yyscanner,yytext);
                                 incLineNr(yyscanner);
                               }
	YY_BREAK
case 226:
YY_RULE_SETUP
#line 1616 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // escaped char
                                 addToString(yyscanner,yytext);
                               }
	YY_BREAK
case 227:
YY_RULE_SETUP
#line 1619 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // triple double quotes
                                 addToString(yyscanner,yytext);
                               }
	YY_BREAK
case 228:
YY_RULE_SETUP
#line 1622 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // end of the string
                                 addToString(yyscanner,yytext);
                                 BEGIN(yyextra->stringContext);
                               }
	YY_BREAK
case 229:
YY_RULE_SETUP
#line 1626 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // normal chars
                                 addToString(yyscanner,yytext);
                               }
	YY_BREAK
case 230:
YY_RULE_SETUP
#line 1629 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // normal char
                                 addToString(yyscanner,yytext);
                               }
	YY_BREAK


case 231:
/* rule 231 can match eol */
YY_RULE_SETUP
#line 1635 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // line continuation
                                 addToString(yyscanner,yytext);
                                 incLineNr(yyscanner);
                               }
	YY_BREAK
case 232:
YY_RULE_SETUP
#line 1639 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // escaped char
                                 addToString(yyscanner,yytext);
                               }
	YY_BREAK
case 233:
YY_RULE_SETUP
#line 1642 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // triple single quotes
                                 addToString(yyscanner,yytext);
                               }
	YY_BREAK
case 234:
YY_RULE_SETUP
#line 1645 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // end of the string
                                 addToString(yyscanner,yytext);
                                 BEGIN(yyextra->stringContext);
                               }
	YY_BREAK
case 235:
YY_RULE_SETUP
#line 1649 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // normal chars
                                 addToString(yyscanner,yytext);
                               }
	YY_BREAK
case 236:
YY_RULE_SETUP
#line 1652 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // normal char
                                 addToString(yyscanner,yytext);
                               }
	YY_BREAK


case 237:
#line 1659 "/build/doxygen/src/build/generated_src/pyscanner.l"
case 238:
YY_RULE_SETUP
#line 1659 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          *yyextra->copyString << yytext;
                          if (yyextra->doubleQuote==(yytext[0]=='"'))
                          {
                            BEGIN(yyextra->stringContext);
                          }
                        }
	YY_BREAK
case 239:
/* rule 239 can match eol */
YY_RULE_SETUP
#line 1668 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          lineCount(yyscanner);
                          *yyextra->copyString << yytext;
                        }
	YY_BREAK
case 240:
/* rule 240 can match eol */
YY_RULE_SETUP
#line 1672 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          incLineNr(yyscanner);
                          *yyextra->copyString << yytext;
                        }
	YY_BREAK
case 241:
YY_RULE_SETUP
#line 1676 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          *yyextra->copyString << *yytext;
                        }
	YY_BREAK


case 242:
YY_RULE_SETUP
#line 1682 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a comment block
                          yyextra->doubleQuote=TRUE;
                          yyextra->decoratorCommentStr.str(std::string());
                          yyextra->copyString=&yyextra->decoratorCommentStr;
                          yyextra->stringContext=YY_START;
                          BEGIN(TripleString);
                        }
	YY_BREAK
case 243:
YY_RULE_SETUP
#line 1690 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ // start of a comment block
                          yyextra->doubleQuote=FALSE;
                          yyextra->decoratorCommentStr.str(std::string());
                          yyextra->copyString=&yyextra->decoratorCommentStr;
                          yyextra->stringContext=YY_START;
                          BEGIN(TripleString);
                        }
	YY_BREAK
case 244:
YY_RULE_SETUP
#line 1697 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->stringContext=YY_START;
                          yyextra->decoratorCommentStr.str(std::string());
                          yyextra->copyString=&yyextra->decoratorCommentStr;
                          BEGIN( SingleQuoteString );
                        }
	YY_BREAK
case 245:
YY_RULE_SETUP
#line 1703 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->stringContext=YY_START;
                          yyextra->decoratorCommentStr.str(std::string());
                          yyextra->copyString=&yyextra->decoratorCommentStr;
                          BEGIN( DoubleQuoteString );
                        }
	YY_BREAK
case 246:
YY_RULE_SETUP
#line 1709 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->decoratorRound++;
                        }
	YY_BREAK
case 247:
YY_RULE_SETUP
#line 1712 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          yyextra->decoratorRound--;
                          if (!yyextra->decoratorRound) BEGIN( Search );
                        }
	YY_BREAK
case 248:
/* rule 248 can match eol */
YY_RULE_SETUP
#line 1716 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                          incLineNr(yyscanner);
                        }
	YY_BREAK
case 249:
YY_RULE_SETUP
#line 1719 "/build/doxygen/src/build/generated_src/pyscanner.l"
{ }
	YY_BREAK

/* ------------ End rules -------------- */
/*
<*>({NONEMPTY}|{EXPCHAR}|{BB})           { // This should go one character at a time.
                                 // printf("[pyscanner] '%s' [ state %d ]  [line %d] no match\n",
                                 //       yytext, YY_START, yyextra->yyLineNr);

                               }
  */
case 250:
/* rule 250 can match eol */
YY_RULE_SETUP
#line 1732 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                                 //printf("[pyscanner] %d NEWLINE [line %d] no match\n",
                                 //       YY_START, yyextra->yyLineNr);

                                 lineCount(yyscanner);
                               }
	YY_BREAK
case 251:
YY_RULE_SETUP
#line 1739 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                                 //fprintf(stderr,"Quote: %d\n",YY_START);
                               }
	YY_BREAK
case 252:
YY_RULE_SETUP
#line 1743 "/build/doxygen/src/build/generated_src/pyscanner.l"
{
                                 //printf("[pyscanner] '%s' [ state %d ]  [line %d] no match\n",
                                 //       yytext, YY_START, yyextra->yyLineNr);

                               }
	YY_BREAK
case 253:
YY_RULE_SETUP
#line 1750 "/build/doxygen/src/build/generated_src/pyscanner.l"
ECHO;
	YY_BREAK
#line 5408 "/build/doxygen/src/build/generated_src/pyscanner_intermediate.cpp"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(Search):
			case YY_STATE_EOF(SearchMemVars):
			case YY_STATE_EOF(TripleComment):
			case YY_STATE_EOF(SpecialComment):
			case YY_STATE_EOF(FunctionDec):
			case YY_STATE_EOF(FunctionParams):
			case YY_STATE_EOF(FunctionAnnotation):
			case YY_STATE_EOF(FunctionTypeAnnotation):
			case YY_STATE_EOF(FunctionParamDefVal):
			case YY_STATE_EOF(ClassDec):
			case YY_STATE_EOF(ClassInheritance):
			case YY_STATE_EOF(ClassCaptureIndent):
			case YY_STATE_EOF(VariableDec):
			case YY_STATE_EOF(VariableAtom):
			case YY_STATE_EOF(SingleQuoteString):
			case YY_STATE_EOF(DoubleQuoteString):
			case YY_STATE_EOF(TripleString):
			case YY_STATE_EOF(SingleQuoteStringIgnore):
			case YY_STATE_EOF(DoubleQuoteStringIgnore):
			case YY_STATE_EOF(FromMod):
			case YY_STATE_EOF(FromModItem):
			case YY_STATE_EOF(Import):
			case YY_STATE_EOF(TypeHint):
			case YY_STATE_EOF(Decorator):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;
	yy_current_state += YY_AT_BOL();

	yyg->yy_state_ptr = yyg->yy_state_buf;
	*yyg->yy_state_ptr++ = yy_current_state;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 766 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		*yyg->yy_state_ptr++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */

	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 766 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 765);
	if ( ! yy_is_jam )
		*yyg->yy_state_ptr++ = yy_current_state;

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp , yyscan_t yyscanner)
{
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = yyg->yy_n_chars + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

    yyg->yy_state_buf = 0;
    yyg->yy_state_ptr = 0;
    yyg->yy_full_match = 0;
    yyg->yy_lp = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    yyfree ( yyg->yy_state_buf , yyscanner);
    yyg->yy_state_buf  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 1750 "/build/doxygen/src/build/generated_src/pyscanner.l"


//----------------------------------------------------------------------------

static int yyread(yyscan_t yyscanner,char *buf,int max_size)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  int c=0;
  const char *p = yyextra->inputString + yyextra->inputPosition;
  while ( c < max_size && *p ) { *buf++ = *p++; c++; }
  yyextra->inputPosition+=c;
  return c;
}

static void initParser(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  yyextra->protection = Protection::Public;
  yyextra->mtype = MethodTypes::Method;
  yyextra->isStatic = FALSE;
  yyextra->virt = Specifier::Normal;
  yyextra->previous = 0;
  yyextra->packageCommentAllowed = TRUE;
}

static void initEntry(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  //yyextra->current->python = TRUE;
  yyextra->current->protection = yyextra->protection ;
  yyextra->current->mtype      = yyextra->mtype;
  yyextra->current->virt       = yyextra->virt;
  yyextra->current->isStatic   = yyextra->isStatic;
  yyextra->current->lang       = SrcLangExt::Python;
  yyextra->current->type.clear();
  yyextra->current->name.clear();
  yyextra->current->initializer.clear();
  yyextra->commentScanner.initGroupInfo(yyextra->current.get());
  yyextra->isStatic = FALSE;
}

static void newEntry(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  if (yyextra->current->name.isEmpty())
  {
    initEntry(yyscanner);
    return;
  }
  bool found = false;
  if (yyextra->checkDupEntry)
  {
    for (auto &v : yyextra->current_root->children())
    {
      //printf("candidate %s<->%s section=%s!\n",qPrint(v->name),qPrint(yyextra->current->name), qPrint(v->section.to_string()));
      if (v->name==yyextra->current->name && v->section==yyextra->current->section) // name is already added, don't add it again
      {
        if (v->doc.isEmpty() && !yyextra->current->doc.isEmpty())
        {
          v->doc       = yyextra->current->doc;
          v->docLine   = yyextra->current->docLine;
          v->docFile   = yyextra->current->docFile;
        }
        if (v->brief.isEmpty() && !yyextra->current->brief.isEmpty())
        {
          v->brief     = yyextra->current->brief;
          v->briefLine = yyextra->current->briefLine;
          v->briefFile = yyextra->current->briefFile;
        }
        if (v->type.isEmpty() && !yyextra->current->type.isEmpty())
        {
          //printf("copying type '%s' from '%s' to '%s'\n",qPrint(yyextra->current->type),qPrint(yyextra->current->name),qPrint(v->name));
          v->type      = yyextra->current->type;
        }
        found=true;
        break;
      }
    }
  }
  if (!found)
  {
    yyextra->previous = yyextra->current;
    yyextra->current_root->moveToSubEntryAndRefresh(yyextra->current);
  }
  initEntry(yyscanner);
}

static void addEntry(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;

  auto doc        = yyextra->current->doc;
  auto docLine    = yyextra->current->docLine;
  auto docFile    = yyextra->current->docFile;
  auto brief      = yyextra->current->brief;
  auto briefLine  = yyextra->current->briefLine;
  auto briefFile  = yyextra->current->briefFile;

  yyextra->previous = yyextra->current;
  yyextra->current_root->moveToSubEntryAndRefresh(yyextra->current);
  initEntry(yyscanner);

  yyextra->current->doc        = doc;
  yyextra->current->docLine    = docLine;
  yyextra->current->docFile    = docFile;
  yyextra->current->brief      = brief;
  yyextra->current->briefLine  = briefLine;
  yyextra->current->briefFile  = briefFile;
}

static void setProtection(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  if (!yyextra->current->name.isEmpty() && yyextra->current->name.at(0)=='_')
  {
    if (yyextra->current->name.at(1)=='_') // mark as private
    {
      yyextra->current->protection=Protection::Private;
    }
    else // mark as protected
    {
      yyextra->current->protection=Protection::Protected;
    }
  }
}

static void docVariable(yyscan_t yyscanner,const char *name)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  yyextra->current->name = name;
  yyextra->current->section=EntryType::makeVariable();
  yyextra->current->fileName  = yyextra->fileName;
  yyextra->current->startLine = yyextra->yyLineNr;
  yyextra->current->bodyLine  = yyextra->yyLineNr;
  yyextra->current->type.clear();
  setProtection(yyscanner);
  yyextra->checkDupEntry = true;
}

static void newVariable(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  setProtection(yyscanner);
  if (yyextra->current_root->section.isCompound()) // mark as class variable
  {
    yyextra->current->isStatic = TRUE;
  }
  newEntry(yyscanner);
}

static void addVariable(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  setProtection(yyscanner);
  if (yyextra->current_root->section.isCompound()) // mark as class variable
  {
    yyextra->current->isStatic = TRUE;
  }
  addEntry(yyscanner);
}

static void newFunction(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  if (yyextra->current->name.startsWith("__") && yyextra->current->name.endsWith("__"))
  {
    // special method name, see
    // http://docs.python.org/ref/specialnames.html
    yyextra->current->protection=Protection::Public;
  }
  else
  {
    setProtection(yyscanner);
  }
}

static inline int computeIndent(const char *s)
{
  int col=0;
  int tabSize=Config_getInt(TAB_SIZE);
  const char *p=s;
  char c;
  while ((c=*p++))
  {
    if (c==' ') col++;
    else if (c=='\t') col+=tabSize-(col%tabSize);
    else break;
  }
  return col;
}

static QCString findPackageScopeFromPath(yyscan_t yyscanner,const QCString &path)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  auto it = yyextra->packageNameCache.find(path.str());
  if (it!=yyextra->packageNameCache.end())
  {
    return it->second;
  }
  FileInfo pf(path.str()+"/__init__.py"); // found package initialization file
  if (pf.exists())
  {
    int i=path.findRev('/');
    if (i!=-1)
    {
      QCString scope = findPackageScopeFromPath(yyscanner,path.left(i));
      if (!scope.isEmpty())
      {
        scope+="::";
      }
      scope+=path.mid(i+1);
      yyextra->packageNameCache.emplace(path.str(),scope.str());
      return scope;
    }
  }
  return "";
}

static QCString findPackageScope(yyscan_t yyscanner,const QCString &fileName)
{
  if (fileName.isEmpty()) return fileName;
  FileInfo fi(fileName.str());
  return findPackageScopeFromPath(yyscanner,fi.dirPath(true));
}

static void addFrom(yyscan_t yyscanner,bool all)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  QCString item=all ? yyextra->packageName : yyextra->packageName+"."+yytext;
  yyextra->current->name=removeRedundantWhiteSpace(substitute(item,".","::"));
  yyextra->current->fileName = yyextra->fileName;
  //printf("Adding using declaration: found:%s:%d name=%s\n",qPrint(yyextra->fileName),yyextra->yyLineNr,qPrint(yyextra->current->name));
  yyextra->current->section=all ? EntryType::makeUsingDir() : EntryType::makeUsingDecl();
  yyextra->current_root->moveToSubEntryAndRefresh(yyextra->current);
  initEntry(yyscanner);
}
//-----------------------------------------------------------------------------

static void lineCount(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  DBG_CTX((stderr,"yyextra->yyLineNr=%d\n",yyextra->yyLineNr));
  for (const char *p = yytext; *p; ++p)
  {
    yyextra->yyLineNr += (*p == '\n') ;
  }
}

static void incLineNr(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  DBG_CTX((stderr,"yyextra->yyLineNr=%d\n",yyextra->yyLineNr));
  yyextra->yyLineNr++;
}

//-----------------------------------------------------------------
static void startCommentBlock(yyscan_t yyscanner,bool brief)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  if (brief)
  {
    yyextra->current->briefFile = yyextra->fileName;
    yyextra->current->briefLine = yyextra->yyLineNr;
  }
  else
  {
    yyextra->current->docFile = yyextra->fileName;
    yyextra->current->docLine = yyextra->yyLineNr;
  }
}

static void handleCommentBlock(yyscan_t yyscanner,const QCString &doc,bool brief)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  //printf("handleCommentBlock(doc=[%s] brief=%d yyextra->docBlockInBody=%d yyextra->docBlockJavaStyle=%d\n",
  //    qPrint(doc),brief,yyextra->docBlockInBody,yyextra->docBlockJavaStyle);

  // TODO: Fix me
  yyextra->docBlockInBody=FALSE;

  if (!yyextra->current->doc.isEmpty())
  {
    yyextra->current->doc=yyextra->current->doc.stripWhiteSpace()+"\n\n";
  }
  if (yyextra->docBlockInBody && yyextra->previous && !yyextra->previous->doc.isEmpty())
  {
    yyextra->previous->doc=yyextra->previous->doc.stripWhiteSpace()+"\n\n";
  }

  int position = 0;
  bool needsEntry = false;
  int lineNr = brief ? yyextra->current->briefLine : yyextra->current->docLine;
  Markdown markdown(yyextra->fileName,lineNr);
  GuardedSectionStack guards;
  QCString strippedDoc = stripIndentation(doc,true);
  //printf("stippedDoc=[%s]\n",qPrint(strippedDoc));
  QCString processedDoc = Config_getBool(MARKDOWN_SUPPORT) ? markdown.process(strippedDoc,lineNr) : strippedDoc;
  while (yyextra->commentScanner.parseCommentBlock(
        yyextra->thisParser,
        (yyextra->docBlockInBody && yyextra->previous) ? yyextra->previous.get() : yyextra->current.get(),
        processedDoc, // text
        yyextra->fileName,   // file
        lineNr,
        yyextra->docBlockInBody ? FALSE : brief,
        yyextra->docBlockJavaStyle, // javadoc style // or FALSE,
        yyextra->docBlockInBody,
        yyextra->protection,
        position,
        needsEntry,
        Config_getBool(MARKDOWN_SUPPORT),
        &guards
       )
     ) // need to start a new entry
  {
    if (needsEntry)
    {
      newEntry(yyscanner);
    }
  }
  if (needsEntry)
  {
    newEntry(yyscanner);
  }

}

static void endOfDef(yyscan_t yyscanner,int correction)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  //printf("endOfDef at=%d\n",yyextra->yyLineNr);
  if (yyextra->bodyEntry)
  {
    yyextra->bodyEntry->endBodyLine  = yyextra->yyLineNr-correction;
    yyextra->bodyEntry = 0;
  }
  newEntry(yyscanner);
  //yyextra->insideConstructor = FALSE;
}

static inline void addToString(yyscan_t yyscanner,const char *s)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  if (yyextra->copyString) (*yyextra->copyString) << s;
}

static void initTriDoubleQuoteBlock(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  yyextra->docBlockContext   = YY_START;
  yyextra->docBlockInBody    = FALSE;
  yyextra->docBlockJavaStyle = TRUE;
  yyextra->docBlockSpecial   = yytext[strlen(yytext) - 1]=='!' || !Config_getBool(PYTHON_DOCSTRING);
  yyextra->docBlock.clear();
  yyextra->commentIndent = yyextra->curIndent;
  yyextra->doubleQuote = TRUE;
  startCommentBlock(yyscanner,FALSE);
}

static void initTriSingleQuoteBlock(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  yyextra->docBlockContext   = YY_START;
  yyextra->docBlockInBody    = FALSE;
  yyextra->docBlockJavaStyle = TRUE;
  yyextra->docBlockSpecial   = yytext[strlen(yytext) - 1]=='!' || !Config_getBool(PYTHON_DOCSTRING);
  yyextra->docBlock.clear();
  yyextra->commentIndent = yyextra->curIndent;
  yyextra->doubleQuote = FALSE;
  startCommentBlock(yyscanner,FALSE);
}

static void initSpecialBlock(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  yyextra->docBlockContext   = YY_START;
  yyextra->docBlockInBody    = FALSE;
  yyextra->docBlockJavaStyle = TRUE;
  yyextra->docBrief = TRUE;
  yyextra->docBlock.clear();
  yyextra->commentIndent = yyextra->curIndent;
  startCommentBlock(yyscanner,FALSE);
}

static void searchFoundDef(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  yyextra->current->fileName  = yyextra->fileName;
  yyextra->current->startLine = yyextra->yyLineNr;
  yyextra->current->bodyLine  = yyextra->yyLineNr;
  yyextra->current->section = EntryType::makeFunction();
  yyextra->current->lang = SrcLangExt::Python;
  yyextra->current->virt = Specifier::Normal;
  yyextra->current->isStatic = yyextra->isStatic;
  yyextra->current->mtype = yyextra->mtype = MethodTypes::Method;
  yyextra->current->type.clear();
  yyextra->current->name.clear();
  yyextra->current->args.clear();
  yyextra->current->argList.clear();
  yyextra->packageCommentAllowed = FALSE;
  yyextra->isStatic=FALSE;
  //printf("searchFoundDef at=%d\n",yyextra->yyLineNr);
}

static void searchFoundClass(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  yyextra->current->section = EntryType::makeClass();
  yyextra->current->argList.clear();
  yyextra->current->type += "class" ;
  yyextra->current->fileName  = yyextra->fileName;
  yyextra->current->startLine  = yyextra->yyLineNr;
  yyextra->current->bodyLine  = yyextra->yyLineNr;
  yyextra->packageCommentAllowed = FALSE;
}

//----------------------------------------------------------------------------

static void parseCompounds(yyscan_t yyscanner,std::shared_ptr<Entry> rt)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  //printf("parseCompounds(%s)\n",qPrint(rt->name));
  for (size_t i=0; i<rt->children().size(); ++i)
  {
    std::shared_ptr<Entry> ce = rt->children()[i];
    if (!ce->program.empty())
    {
      //fprintf(stderr,"parseCompounds: -- %s (line %d) ---------\n%s\n---------------\n",
      //  qPrint(ce->name), ce->bodyLine, qPrint(ce->program));
      // init scanner state
      yyextra->programStr = ce->program.str();
      yyextra->inputString = yyextra->programStr.data();
      yyextra->inputPosition = 0;
      yyextra->firstPass     = false;
      pyscannerYYrestart( nullptr, yyscanner );
      if (ce->section.isCompound())
      {
        yyextra->specialBlock = false;
        yyextra->current_root = ce;
        BEGIN( Search );
      }
      else if (ce->parent())
      {
        yyextra->current_root = rt;
        //printf("Searching for member variables in %s parent=%s\n",
        //    qPrint(ce->name),qPrint(ce->parent->name));
        BEGIN( SearchMemVars );
      }
      yyextra->fileName = ce->fileName;
      yyextra->yyLineNr   = ce->bodyLine ;
      yyextra->current = std::make_shared<Entry>();
      initEntry(yyscanner);

      yyextra->checkDupEntry = false;

      QCString name = ce->name;
      yyextra->commentScanner.enterCompound(yyextra->fileName,yyextra->yyLineNr,name);

      pyscannerYYlex(yyscanner) ;
      yyextra->lexInit=TRUE;

      yyextra->programStr.clear();
      ce->program.str(std::string());

      yyextra->commentScanner.leaveCompound(yyextra->fileName,yyextra->yyLineNr,name);

    }
    parseCompounds(yyscanner,ce);
  }
}

//----------------------------------------------------------------------------


static void parseMain(yyscan_t yyscanner, const QCString &fileName,const char *fileBuf,const std::shared_ptr<Entry> &rt)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  initParser(yyscanner);

  if (fileBuf==nullptr || fileBuf[0]=='\0') return;

  yyextra->inputString = fileBuf;
  yyextra->inputPosition = 0;

  yyextra->protection    = Protection::Public;
  yyextra->mtype         = MethodTypes::Method;
  yyextra->isStatic      = false;
  yyextra->virt          = Specifier::Normal;
  yyextra->current_root  = rt;
  yyextra->specialBlock  = false;

  yyextra->yyLineNr      = 1 ;
  yyextra->fileName      = fileName;
  yyextra->checkDupEntry = false;
  yyextra->firstPass     = true;
  //setContext();
  msg("Parsing file {}...\n",yyextra->fileName);

  FileInfo fi(fileName.str());
  yyextra->moduleScope = findPackageScope(yyscanner,fileName);
  QCString baseName=fi.baseName();
  if (baseName!="__init__") // package initializer file is not a package itself
  {
    if (!yyextra->moduleScope.isEmpty())
    {
      yyextra->moduleScope+="::";
    }
    yyextra->moduleScope+=baseName;
  }

  // add namespaces for each scope
  QCString scope = yyextra->moduleScope;
  int startPos = 0;
  int pos = 0;
  do
  {
    pos = scope.find("::",startPos);
    startPos=pos+2;
    if (pos==-1) pos=(int)scope.length();
    yyextra->current            = std::make_shared<Entry>();
    initEntry(yyscanner);
    yyextra->current->name      = scope.left(pos);
    yyextra->current->section   = EntryType::makeNamespace();
    yyextra->current->type      = "namespace";
    yyextra->current->fileName  = yyextra->fileName;
    yyextra->current->startLine = yyextra->yyLineNr;
    yyextra->current->bodyLine  = yyextra->yyLineNr;
    yyextra->current_root       = yyextra->current;
    rt->moveToSubEntryAndRefresh(yyextra->current);
  } while (pos<(int)scope.length());

  initParser(yyscanner);

  yyextra->commentScanner.enterFile(yyextra->fileName,yyextra->yyLineNr);

  yyextra->current->reset();
  initEntry(yyscanner);
  pyscannerYYrestart(nullptr,yyscanner);
  BEGIN( Search );
  pyscannerYYlex(yyscanner);
  yyextra->lexInit=TRUE;

  yyextra->commentScanner.leaveFile(yyextra->fileName,yyextra->yyLineNr);

  yyextra->programStr.clear();
  yyextra->current_root->program.str(std::string());

  parseCompounds(yyscanner, yyextra->current_root);
}

//----------------------------------------------------------------------------

static void parsePrototype(yyscan_t yyscanner,const QCString &text)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  //printf("**** parsePrototype(%s) begin\n",qPrint(text));
  if (text.isEmpty())
  {
    warn(yyextra->fileName,yyextra->yyLineNr,"Empty prototype found!");
    return;
  }

  yyextra->specialBlock = FALSE;
  yyextra->packageCommentAllowed = FALSE;

  // save scanner state
  YY_BUFFER_STATE orgState = YY_CURRENT_BUFFER;
  yy_switch_to_buffer(yy_create_buffer(nullptr, YY_BUF_SIZE, yyscanner), yyscanner);
  const char *orgInputString = yyextra->inputString;
  int orgInputPosition = yyextra->inputPosition;

  // set new string
  yyextra->inputString = text.data();
  yyextra->inputPosition = 0;
  pyscannerYYrestart( nullptr, yyscanner );

  BEGIN( FunctionDec );

  pyscannerYYlex(yyscanner);
  yyextra->lexInit=TRUE;

  yyextra->current->name = yyextra->current->name.stripWhiteSpace();
  if (yyextra->current->section.isMemberDoc() && yyextra->current->args.isEmpty())
  {
    yyextra->current->section = EntryType::makeVariableDoc();
  }

  // restore original scanner state

  yy_delete_buffer(YY_CURRENT_BUFFER, yyscanner);
  yy_switch_to_buffer(orgState, yyscanner);

  yyextra->inputString = orgInputString;
  yyextra->inputPosition = orgInputPosition;

  //printf("**** parsePrototype end\n");
}

//----------------------------------------------------------------------------

struct PythonOutlineParser::Private
{
  yyscan_t yyscanner;
  pyscannerYY_state state;
};

PythonOutlineParser::PythonOutlineParser() : p(std::make_unique<PythonOutlineParser::Private>())
{
  pyscannerYYlex_init_extra(&p->state,&p->yyscanner);
#ifdef FLEX_DEBUG
  pyscannerYYset_debug(Debug::isFlagSet(Debug::Lex_pyscanner)?1:0,p->yyscanner);
#endif
}

PythonOutlineParser::~PythonOutlineParser()
{
  pyscannerYYlex_destroy(p->yyscanner);
}


void PythonOutlineParser::parseInput(const QCString &fileName,
                                     const char *fileBuf,
                                     const std::shared_ptr<Entry> &root,
                                     ClangTUParser * /*clangParser*/)
{
  struct yyguts_t *yyg = (struct yyguts_t*)p->yyscanner;
  yyextra->thisParser = this;
  DebugLex debugLex(Debug::Lex_pyscanner, __FILE__, qPrint(fileName));
  ::parseMain(p->yyscanner, fileName,fileBuf,root);

  // May print the AST for debugging purposes
  // printAST(global_root);
}

bool PythonOutlineParser::needsPreprocessing(const QCString &) const
{
  return FALSE;
}

void PythonOutlineParser::parsePrototype(const QCString &text)
{
  ::parsePrototype(p->yyscanner,text);
}

//----------------------------------------------------------------------------

#include "pyscanner.l.h"

